#!/usr/bin/perl -w
#
# AUTHORS:
#
# Thomas Klemm (orginal code, concept, and research)
# Egan Ford (this file)
# Ton Hospel (gunzip)
#
# TODO (maybe):
#
# put opcodes in different file?
# put macros in different file
# put new in different file?
# current state as new option
# macros to support numeric expansion
#

use strict;
use Class::Struct;
use Getopt::Long;
use POSIX qw(ceil floor);

struct V => {
	op      => '$',
	code    => '$',
	display => '$',
};

my $ver = 0.85;
my $date = "Tue Apr  1 18:03:11 UTC 2008";
my $mode = shift || "blah";
my $input;
my $output;
my $model = "";
my $in=0;
my %code;
my %ops;
my %macros;
my @outputlines;
my $longestline = 0;
#my $myname = $0;
my $myname = "vcomp.pl";
my $spacer = 6;
my $columns = 0;
my $charcolumns = 0;
my $codeonly = 0;
my $linecode = 0;
my $strip;
my $dict;
my $nst;
my $newnst;
my $src;
my $help = 0;
my $version = 0;
my @nstxml = ();
my $phase = 3;
my $macro = "";
my $usenew = 0;

###gunzip start
use constant FTEXT    => 1;
use constant FHCRC    => 2;
use constant FEXTRA   => 4;
use constant FNAME    => 8;
use constant FCOMMENT => 16;
my ($fin, $crc16, @crc32, @lit_base, @dist_base, $bits_val, $bits_have);
my @lit_extra = (-1,0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,0,-2,-2);
my @dist_extra = (0,0,0,0,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,-1,-1);
my @alpha_map = (16, 17, 18, 0, 8, 7, 9, 6, 10, 5, 11, 4, 12, 3, 13, 2, 14, 1, 15);
my ($static_lit_code, $static_dist_code);
###gunzip end

if($mode =~ /^-*v/) {
	print "\nVoyager Compiler Version $ver $date\n\n";
	exit(0);
}
elsif($mode =~ /^d/) {
	GetOptions(
		"c=s" => \$columns,
		"cc=s" => \$charcolumns,
		"h|help" => \$help,
		"v|version" => \$version,
	) or usage() and exit(1);
	$mode = "dict";
	$model = shift;
	if($help || !$model) {
print <<EOF;

$myname $mode [-c|-cc n] <model>

-c n       Print output in n columns.
-cc n      Print output using x columns that can fit in n characters.

<model>    Must be 11C, 12C, 15C, or 16C.

E.g.  11C dictionary in 2 columns:

$myname $mode -c 2 11C

E.g.  15C dictionary in x columns that can fix in 80 characters:

$myname $mode -cc 80 15C
      
EOF
		exit(0);
	}
}
elsif($mode =~ /^l/) {
	GetOptions(
		"c=s" => \$columns,
		"cc=s" => \$charcolumns,
		"code" => \$codeonly,
		"linecode" => \$linecode,
		"h|help" => \$help,
		"v|version" => \$version,
	) or usage() and exit(1);
	$mode = "list";
	$nst = shift;
	if($help || !$nst) {
print <<EOF;

$myname $mode [-c|-cc n] [-code|-linecode] <file>

-c n       Print output in n columns.
-cc n      Print output using x columns that can fit in n characters.
-code      Print only the text op code.
-linecode  Print only the line number and the text op code.

<file>     Is an existing Nonpareil State file.

E.g.  To list your 15C program(s) with 2 columns, statements only:

$myname $mode -c 2 -code 15C.nst

E.g.  To list your 15C program(s) with 1 column, line numbers and statements:

$myname $mode -linecode 15C.nst

EOF
	exit(0);
	}
}
elsif($mode =~ /^c/) {
	GetOptions(
		"c=s" => \$columns,
		"cc=s" => \$charcolumns,
		"nst=s" => \$nst,
		"new=s" => \$model,
		"strip=s" => \$strip,
		"p|phase=s" => \$phase,
		"h|help" => \$help,
		"v|version" => \$version,
	) or usage() and exit(1);
	if($model && !$nst) {
		usage();
		exit(1);
	}
	$mode = "comp";
	$src = shift;
	if($help || !$src || !$nst) {
print <<EOF;

$myname $mode [-help] [-strip n] [-phase 1|2] [-c|-cc n] [-new <model>] -nst <file> <code>

-strip n      Strip off n characters from each line of <code>.
-phase 1|2    Stop compile after phase 1 or 2.  Use -c|-cc to format.
-c n          Print output in n columns.
-cc n         Print output using x columns that can fit in n characters.
-new <model>  Create new <file> using an empty <model>.
-nst <file>   Input and/or output file.

<model>       Must be 11C, 12C, 15C, or 16C.
<file>        Is an existing or new Nonpareil State file.
<code>        Is your text source code.

E.g. To compile foo.txt and merge with existing 12C.nst:

$myname $mode -nst 12C.nst foo.txt

E.g. To compile bar.txt for the 15C as a new 15C.nst:

$myname $mode -new 15C -nst 15C.nst bar.txt

EOF
		exit(0);
	}
}
else {
	usage();
	exit(1);
}

if($columns && $charcolumns) {
	print "\n-c or -cc\n\n";
	exit(1);
}
if($codeonly && $linecode) {
	print "\n-code or -linecode\n\n";
	exit(1);
}

if($nst && $model) {
	$usenew = 1;
}

if($nst && !$model) {
	my $xml;
	my $fout;
	my $fine;

	open($fout,'>',\$xml);
	if(!open($fine,$nst)) {
		print "\nCannot read $nst\n\n";
		exit(1);
	}
	my ($ret,$errormsg) = gunzip($fine,$fout);

	if($ret == 1) {
		seek($fine, 0, 0);
		while(<$fine>) {
			chomp();
			if(/^\s*$/) {
				next;
			}
			if(/model=/) {
				my $m = $_;
				$m =~ s/.*?model=\"(.*?)\".*/$1/;
				$model=$m;
			}
			push @nstxml, m|(<.*?>)|g;
		}
	}
	else {
		@nstxml = $xml =~ m|(<.*?>)|g;
		foreach(@nstxml) {
			if(/model=/) {
				my $m = $_;
				$m =~ s/.*?model=\"(.*?)\".*/$1/;
				$model=$m;
			}
		}
	}

	close($fine);
	close($fout);
}

if($model !~ m/1[1256][Cc]/) {
	print "Model: $model unsupported\n";
	exit(1);
}
$model =~ tr/c/C/;

while(<DATA>) {
	chomp();

	if(/$model Opcode Start/ .. /$model Opcode End/) {
		s/^#.*$//;
		if(/^\s*$/) {
			next;
		}
		if(/^$model Opcode/) {
			next;
		}

		s/^\s*//;
		s/ \|$//;
		my $v = V->new();
		my ($op,$cod,$dis) = split(/\s+\|\s+/);
		$v->op($op);
		$v->display($dis);
		$v->code($cod);
		$cod =~ tr/A-Z/a-z/;
		$cod =~ s/\s//g;
		$code{$cod} = $v;
		if(!$ops{$op}) {
			$ops{$op} = $v;
		}
	}

	if(/$model Macro Start/ .. /$model Macro End/) {
		s/^#.*$//;
		if(/^\s*$/) {
			next;
		}
		if(/^$model Macro/) {
			next;
		}
		if(/^\&/) {
			$macro = $_;
			$macro =~ s/^\&//;
			next;
		}
		if($macro) {
			push @{$macros{$macro}}, $_;
		}
	}

	if((/$model New Start/ .. /$model New End/) && $usenew == 1) {
		s/^#.*$//;
		if(/^\s*$/) {
			next;
		}
		if(/^$model New/) {
			next;
		}

		push(@nstxml,$_);
	}
}

#foreach(@nstxml) { print "$_\n"; } exit;
#my $key; foreach $key (keys %macros) { print "$key \t @{$macros{$key}}\n"; } exit;

if($nst && $src) {
	my @ins;
	my $cod;
	my $macro;
	my $line = 0;
	my @lbl;
	my %vlbl;
	my @bytes;

	if(!open(SRC,$src)) {
		print "\nCannot read $src\n\n";
		exit(1);
	}

	if($phase < 1) {
		exit(0);
	}

	print STDERR "\nPhase 1: Preprocessor\n";

	while(<SRC>) {
		$line++;
		chomp();
		s/\;.*$//;
		if($strip) {
			s/^.{$strip}//;
		}
		s/\s*$//;
		s/^\s*//;
		if(/^\s*$/) {
			next;
		}

		s/://g;
		s/^f\s+//;
		s/^g\s+//;
		$cod = $_;
		$cod =~ tr/A-Z/a-z/;
		$cod =~ s/\s//g;
		if(/^\&/) {
			$macro = $_;
			$macro =~ s/^\&//;
			my $mline = 0;
			if($macros{$macro}) {
				for my $cod (@{$macros{$macro}}) {
					$mline++;
					$cod =~ tr/A-Z/a-z/;
					$cod =~ s/\s//g;
					if($cod =~ m/^lbl/ && $model eq "12C") {
						my $tcod = $cod;
						$tcod =~ s/^lbl//;
						if($tcod =~ m/[a-z][a-z0-9]*/) {
							if($vlbl{$tcod}) {
								print STDERR "\nERROR: duplicate virtual label: $cod, in macro: \&$macro, line: $line.$mline\n\n";
								exit(1);
							}
							$vlbl{$tcod} = $#ins + 2;
							#print "VL: $tcod $vlbl{$tcod}\n";
							next;
						}
					}
					if($cod =~ m/^lbl/) {
						my $label = $_;
						foreach(@lbl) {
							if($cod eq $_) {
								print STDERR "WARNING: duplicate label: $label, in macro: \&$macro, line: $line.$mline\n";
								last;
							}
						}
						push(@lbl,$cod);
					}
					if(!$code{$cod}) {
						if($cod =~ m/^gto/ && $model eq "12C") {
							#let it ride
							push(@ins,$cod);
						}
						else {
							print STDERR "\nERROR: illegal instruction: $cod, in macro: \&$macro, line: $line.$mline\n\n";
							exit(1);
						}
					}
					else {
						push(@ins,$cod);
					}
				}
			}
			else {
				print STDERR "\nERROR: macro not define: $_, line: $line\n\n";
				exit(1);
			}
			next;
		}
		if(/^-?(\d|\.|,)+[Ee]?-?[0-9]?[0-9]?$/) {
			my $neg = 0;

			if(/^-/) {
				$neg = 1;
				s/^-//;
			}

			foreach(split(//,$_)) {
				if(/,/) {
					next;
				}
				if(/(e|E)/) {
					if($neg) {
						push(@ins,"chs");
						$neg = 0;
					}
					push(@ins,"eex");
					next;
				}
				push(@ins,$_);
			}
			if($neg) {
				push(@ins,"chs");
			}
			next;
		}
		if($cod =~ m/^lbl/ && $model eq "12C") {
			my $tcod = $cod;
			$tcod =~ s/^lbl//;
			if($tcod =~ m/[a-z][a-z0-9]*/) {
				if($vlbl{$tcod}) {
					print STDERR "\nERROR: duplicate virtual label: $_, line: $line\n\n";
					exit(1);
				}
				$vlbl{$tcod} = $#ins + 2;
				#print "VL: $tcod $vlbl{$tcod}\n";
				next;
			}
		}
		if(!$code{$cod}) {
			if($cod =~ m/^gto/ && $model eq "12C") {
				#let it ride
				push(@ins,$cod);
			}
			else {
				print STDERR "\nERROR: illegal instruction: $_, line: $line\n\n";
				exit(1);
			}
		}
		else {
			push(@ins,$cod);
		}
		if($cod =~ m/^lbl/) {
			my $label = $_;
			foreach(@lbl) {
				if($cod eq $_) {
					print STDERR "WARNING: duplicate label: $label, line: $line\n";
					last;
				}
			}
			push(@lbl,$cod);
		}
	}

	if($phase < 2) {
		my $n=1;
		foreach(@ins) {
			my $opcode = "----";
			my $tcode = $_;
			if($code{$_}) {
				$opcode = $code{$_}->op;
				$tcode = $ops{$opcode}->code;
				if(length($code{$_}->op) == 2) {
					$opcode = "  " . $opcode;
				}
			}
			my $line = sprintf("%03d %s %s",$n++,$opcode,$tcode);
			push(@outputlines,$line);
			if(length($line) > $longestline) {
				$longestline = length($line);
			}
		}
		print "\n";
		dumpoutput();
		exit(0);
	}

	print STDERR "Phase 2: Check GTOs\n";

	if($model eq "12C") {
		my $lc = 0;
		foreach(@ins) {
			$lc++;
			if(/^gto/) {
				my $gto = $_;
				$gto =~ s/^gto//;
				if($gto =~ m/[a-z]+/) {
					if($vlbl{$gto}) {
						my $dest = sprintf("gto%02d",$vlbl{$gto});
						$ins[$lc-1] = $dest;
						#print "$dest\n";
					}
					else {
						$gto =~ tr/a-z/A-Z/;
						printf STDERR "\nERROR: Virtual GTO $gto goes nowhere, post processed line: %d\n\n",$lc;
						exit(1);
					}
				}
				else {
					if($gto > $#ins + 1) {
						printf STDERR "\nERROR: GTO %02d goes nowhere, post processed line: %d\n\n",$gto,$lc;
						exit(1);
					}
				}
			}
		}
	}
	else {
		my $lc = 0;
		foreach(@ins) {
			$lc++;
			if(/^gto/) {
				my $gto = $_;
				$gto =~ s/^gto//;
				my $ok = 0;
				foreach(@lbl) {
					if(/lbl$gto/) {
						$ok = 1;
						last;
					}
				}
				if(!$ok) {
					$gto =~ tr/a-z/A-Z/;
					printf STDERR "\nERROR: GTO $gto goes nowhere, post processed line: %d\n\n",$lc;
					exit(1);
				}
			}
		}
	}

	if($phase < 3) {
		my $n=1;
		foreach(@ins) {
			my $opcode = "----";
			my $tcode = $_;
			if($code{$_}) {
				$opcode = $code{$_}->op;
				$tcode = $ops{$opcode}->code;
				if(length($code{$_}->op) == 2) {
					$opcode = "  " . $opcode;
				}
			}
			my $line = sprintf("%03d %s %s",$n++,$opcode,$tcode);
			push(@outputlines,$line);
			if(length($line) > $longestline) {
				$longestline = length($line);
			}
		}
		print "\n";
		dumpoutput();
		exit(0);
	}

	print STDERR "Phase 3: Compile\n";

	foreach(@ins) {
		if(length($code{$_}->op) == 4) {
			push(@bytes,$code{$_}->op =~ m/(..)(..)/);
		}
		else {
			push(@bytes,$code{$_}->op)
		}
	}

	my $bytecount = $#ins+1;

	if(!open(NST,'>',$nst)) {
		print "\nCannot write to $nst\n\n";
		exit(1);
	}

	if($model =~ m/^1[16]C$/) {
		my $idx = $#bytes;
		my $byte = $idx % 7 + 1; 
		my $addr = 0xfc - int($idx / 7);  
		my $xml = "";

		if($bytecount > 203) {
			print STDERR "\nERROR: Too many bytes: $bytecount > 203\n\n";
			exit(1);
		}

		foreach(@nstxml) {
			print NST "$_\n";
			if(/addr="00a"/) {
				last;
			}
		}

		for my $addr (reverse (0xe0 .. 0xfc)) {
			my @data = splice @bytes, 0, 7;
			$#data = 6;
			$xml = sprintf("<loc addr=\"%03x\" data=\"%s\"/>\n", $addr, (join '', map { $_ || '00' } reverse @data)) . $xml;
		}
		print NST $xml;

		foreach(@nstxml) {
			if(/addr="0fd"/) {
				print NST "$_\n";
			}
		}

		foreach(@nstxml) {
			if(/addr="0fe"/) {
				s/^(.*?data=".{11}).*/$1/;
				print NST $_;
				printf NST "%01d%02x\"/>\n",$byte,$addr;
			}
		}

		foreach(@nstxml) {
			if(/addr="0ff"/) {
				print NST "$_\n";
			}
		}

		printf NST "</memory>\n</state>\n";
	}

	if($model eq "15C") {
		my $idx = $#bytes;
		my $byte = $idx % 7 + 1;
		my $addr = 0xff - int($idx / 7);
		my $xml = "";
	
		if($bytecount > 448) {
			print STDERR "\nERROR: Too many bytes: $bytecount > 448\n\n";
			exit(1);
		}

		foreach(@nstxml) {
			print NST "$_\n";
			if(/addr="016"/) {
				s/^(.*?data=".{11}).*/$1/;
				print NST $_;
				printf NST "%01d%02x\"/>\n",$byte,$addr;
				last;
			}
		}

		foreach(@nstxml) {
			if(/addr="01[789a]"/) {
				print NST "$_\n";
			}
			if(/addr="01a"/) {
				last;
			}
		}

		for my $addr (reverse (0xc0 .. 0xff)) {
			my @data = splice @bytes, 0, 7;
			$#data = 6;
			$xml = sprintf("<loc addr=\"%03x\" data=\"%s\"/>\n", $addr, (join '', map { $_ || '00' } reverse @data)) . $xml;
		}
		print NST $xml;

		printf NST "</memory>\n</state>\n";
	}

	if($model eq "12C") {
		my @rbytes = reverse(@bytes);
		my $first = pop(@rbytes);
		@bytes = reverse(@rbytes);
		my $idx = $#bytes;
		my $byte = $idx % 7 + 1;
		my $addr = 0xfd - int($idx / 7);
		my $xml = "";

		if($bytecount > 99) {
			print STDERR "\nERROR: Too many bytes: $bytecount > 99\n\n";
			exit(1);
		}

		foreach(@nstxml) {
			print NST "$_\n";
			if(/addr="0ef"/) {
				last;
			}
		}

		for my $addr (reverse (0xf0 .. 0xfd)) {
			my @data = splice @bytes, 0, 7;
			$#data = 6;
			$xml = sprintf("<loc addr=\"%03x\" data=\"%s\"/>\n", $addr, (join '', map { $_ || '00' } reverse @data)) . $xml;
		}
		print NST $xml;

		foreach(@nstxml) {
			if(/addr="0fe"/) {
				printf NST "<loc addr=\"0fe\" data=\"%02s000000d85%1x00\"/>\n",$first,$addr & 0xf;
				last;
			}
		}

		foreach(@nstxml) {
			if(/addr="0ff"/) {
				print NST "$_\n";
			}
		}

		printf NST "</memory>\n</state>\n";
	}

	print STDERR "Done!\n\n";
	exit(0);
}

if($mode eq "dict") {
	my $key;
	my @codekey = sort {$code{$a}->op cmp $code{$b}->op} keys %code;

#	foreach $key (sort {$code{$a}->code cmp $code{$b}->code} keys %code) {
#		my $v = $code{$key};
	foreach $key (sort {$ops{$a}->code cmp $ops{$b}->code} keys %ops) {
		my $v = $ops{$key};
		my $printline = "";

		$printline .= $v->code;
#		$printline .= " " x (18-length($code{$key}->code));
#		$printline .= " " x (10-length($code{$key}->display));
		$printline .= " " x (18-length($ops{$key}->code));
		$printline .= " " x (10-length($ops{$key}->display));
		$printline .= $v->display;
		push(@outputlines,$printline);
		if(length($printline) > $longestline) {
			$longestline = length($printline);
		}
#new stuff
		my $in = 0;
		my $wkey;
		foreach(@codekey) {
			my $w = $code{$_};

			if($w->op ne $v->op) {
				if($in == 0) {
					next;
				}
				else {
					last;
				}
			}
			$in = 1;
			if($w->code ne $v->code) {
				push(@outputlines,"  " . $w->code);
			}
		}
	}
}

if($nst && !$src) {
	my @nibs;
	my $addr;
	my $byte;
	my $line = 1;

	#print "#$model\n";
	LINE: foreach (@nstxml) {
		while (m|<loc addr="(\w+)" data="(\w+)"/>|g) {
			if($model ne "15C") {
				if ($1 eq '0fe') {
					if($model ne "12C") {
						($byte, $addr) = $2 =~ /(\w)(\w\w)$/;
					}
					else {
						($byte, $addr) = $2 =~ /^(..).*(.)..$/;
						$addr = 'f' . $addr;
						unshift @nibs, reverse split //, $byte;
					}
					last LINE;
				}
			}
			else {
				if ($1 eq '016') {
					($byte, $addr) = $2 =~ /(\w)(\w\w)$/;
				}
				elsif ($1 eq '0c0') {
					@nibs = ();
				}
			}
			unshift @nibs, reverse split //, $2;
		}
	}

	if($model =~ m/^1[16]C$/) {
		splice @nibs, 0, 14;
		$#nibs = 2 * ((0xfc - hex $addr) * 7 + $byte) - 1;
	}
	elsif($model eq "12C") {
		$#nibs = 2 * ((0xfe - hex $addr) * 7) + 1;
	}
	else {
		$#nibs = 2 * ((0xff - hex $addr) * 7 + $byte) - 1;
	}

	if($addr eq "00" || ($model eq "12C" && $byte eq "00")) {
		push(@outputlines,"Empty $model!");
	}
	else {
		while (@nibs) {
			my ($rnfb, $lnfb) = (shift @nibs, shift @nibs);
			my $printline = "";

			$printline = sprintf("%03d ",$line++);
			if ($rnfb eq 'f' && $model eq "15C") {
				my ($rnsb, $lnsb) = (shift @nibs, shift @nibs);
				$printline .= $ops{$lnfb . $rnfb . $lnsb . $rnsb}->display;
				$printline .= "  ";
				$printline .= $ops{$lnfb . $rnfb . $lnsb . $rnsb}->code;
			}
			else {
				my ($lsd, $msd) = ($rnfb, $lnfb);
				$printline .= "- ";
				$printline .= " " x (8-length($ops{$msd . $lsd}->display));
				$printline .= $ops{$msd . $lsd}->display;
				$printline .= "  ";
				$printline .= $ops{$msd . $lsd}->code;
			}

			if($linecode) {
				$printline =~ s/ [-|u] .{8}//;
			}
			if($codeonly) {
				$printline =~ s/\d{3} [-|u] .{10}//;
			}
			if($model eq "12C" && !$codeonly) {
				$printline =~ s/^.//;
			}
			push(@outputlines,$printline);
			if(length($printline) > $longestline) {
				$longestline = length($printline);
			}
		}
	}

	if($model eq "12C") {
		for(my $i=$#outputlines;$i>=0;$i--) {
			if($outputlines[$i] =~ m/GTO 00/) {
				pop(@outputlines);
			}
			else {
				last;
			}
		}
	}
}

#if(($nst || $dict) && !$src) {
if(@outputlines) {
	dumpoutput();
}
exit(0);

sub dumpoutput {
	if($columns == 0) {
		$columns = 1;
	}
	if($charcolumns) {
		$columns = int($charcolumns / ($longestline + $spacer));
	}
	for(my $i = 0;$i < ceil(($#outputlines+1) / $columns); $i++) {
		for(my $j = 0;$j < $columns; $j++) {
			my $line = $outputlines[$i + $j*ceil(($#outputlines+1) / $columns)];

			#if($line) {
			if($i + $j*ceil(($#outputlines+1) / $columns) <= $#outputlines) {
				print $line;
				if($j < $columns) {
					print " " x ($longestline + $spacer - length($line));
				}
			}
		}
		print "\n";
	}
}

sub usage {
print <<EOF;

Voyager Compiler Version $ver $date

Usage:

$myname dict [-help] [-c|-cc n] <model>
         list [-help] [-c|-cc n] [-code|-linecode] <file>
         comp [-help] [-strip n] [-phase 1|2] [-c|-cc n] [-new <model>] -nst <file> <code>

<model>  Must be 11C, 12C, 15C, or 16C.
<file>   Is an existing or new Nonpareil State file.
<code>   Is your text source code.

EOF
}

###gunzip start
# Author: Ton Hospel
# GPL or Perl Artistic, your choice
# http://osdir.com/ml/lang.perl.par/2004-02/plfgT0SMZ9cK.pl

# get arg bytes
sub r {
	my $rc = read($fin, my $result, $_[0]);
	if ($rc) {
		die "Unexpected short read" if $rc != shift;
		return $result;
	}
	die "Unexpected EOF" if defined($rc);
	die "Read error: $!";
}

# get null-terminated string
sub z {
	local $/ = "\0";
	defined(my $result = <$fin>) || die "Unexpected EOF";
	$crc16 = $crc16>>8^$crc32[$crc16&0xff^ord(substr $result,$_,1)]
		for 0..length($result)-1;
	chomp($result) || die "Unexpected short read";
	return $result;
}

sub prepare_tables {
	my $length = 3;
	for (@lit_extra) {
		push @lit_base, $length;
		$length += 1 << $_ if $_ >= 0;
	}
	# Exceptional case
	splice(@lit_base, -3, 3, 258);

	my $dist = 1;
	for (@dist_extra) {
		push @dist_base, $dist;
		$dist += 1 << $_ if $_ >= 0;
	}
	splice(@dist_base, -2, 2);
}

# get arg bits (little endian)
sub b {
	while ($_[0] > $bits_have) {
		$bits_val |= ord(r(1)) << $bits_have;
		$bits_have += 8;
	}
	my $result = $bits_val & (1 << $_[0])-1;
	$bits_val >>= $_[0];
	$bits_have -= shift;
	return $result;
}

# Get one huffman code
sub h {
	my $code = shift;
	my $str = "";
	do {
		if (--$bits_have < 0) {
			my $c = getc($fin);
			if (!defined($c)) {
				die "Read error: $!" if $!;
				die "Unexpected EOF\n";
			}
			$bits_val = ord($c);
			$bits_have = 7;
		}
		$str .= $bits_val & 1;
		$bits_val >>= 1;
	} until exists $code->{$str};
	defined($code->{$str}) || die "Bad code $str";
	return $code->{$str};
}

# construct huffman code
sub make_huffman {
	my $counts = shift;
	my (%code, @counts);
	push @{$counts[$counts->[$_]]}, $_ for 0..$#$counts;
	my $value = 0;
	my $bits = -1;
	for (@counts) {
		$value *= 2;
		next unless ++$bits && $_;
		$code{sprintf"%0${bits}b", $value++} = $_ for @$_;
	}
	# Close the code to avoid infinite loops (and out of memory)
	$code{sprintf"%0${bits}b", $value++} = undef for
		$value .. (1 << $bits)-1;
	@code{0, 1} = () unless %code;
	return \%code;
}

#sub gunzip(**) {
sub gunzip {
	($fin, my $fout) = @_;
	binmode $fin;

	unless (@crc32) {
		my $p=oct reverse sprintf"%032bb0", 0x04C11DB7;
		@crc32 = map{for my$s(0..7) {$_ = $_>>1 ^ ($_&1 && $p)} $_} 0..255;
	}

	while (!eof($fin)) {
		$crc16 = 0xffffffff;

		my $header = r(10);
		my ($id1, $id2, $cm, $flags, $mt, $xflags, $os) = unpack("CCCCVCC", $header);
		if($id1 != 31) {
			return(1,"First id byte should be 31, not $id1");
		}
		if($id2 != 139) {
			return(1,"Second id byte should be 139, not $id2");
		}
		if($cm != 8) {
			return(1,"Only support deflate (method 8), not method $cm");
		}
		if($flags & ~(FTEXT | FHCRC | FEXTRA | FNAME | FCOMMENT)) {
			return(1,"Unhandled flagbits in $flags");
		}
		my $extra;
		if ($flags & FEXTRA) {
			$header .= my $h = r(2);
			$header .= $extra = r(unpack("v", $h));
		}
		$crc16 = $crc16>>8^$crc32[$crc16&0xff^ord(substr $header,$_,1)]
			for 0..length($header)-1;
		my $fname   = z() if $flags & FNAME;
		my $comment = z() if $flags & FCOMMENT;
		if ($flags & FHCRC) {
			$crc16 = ($crc16 ^ 0xffffffff) & 0xffff;
			my $wanted_crc16 = unpack("v", r(2));
			if($crc16 != $wanted_crc16) {
				return(1,"Header CRC16=$crc16, expected $wanted_crc16");
			}
		}

		# New open because we want to be able to decide binmode
		# depending on the segment flags
		$bits_val = $bits_have = 0;

		my $result = "";
		my $final;
		my $crc32 = 0xffffffff;
		my $isize = 0;
		do {
			$final = b(1);
			my $type = b(2);
			#print STDERR "block type $type\n";
			if ($type) {
				my ($lit_code, $dist_code);
				prepare_tables() unless @lit_base;

				if ($type == 1) {
					$lit_code  = $static_lit_code  ||=
						make_huffman([(8)x144,(9)x112, (7)x24, (8)x8]);
					$dist_code = $static_dist_code ||= 
						make_huffman([(5)x32]);
				} elsif ($type == 2) {
					my $hlit  = b(5)+257;
					my $hdist = b(5)+1;
					my $hclen = b(4)+4;
					#print STDERR "hlit=$hlit,hdist=$hdist,hclen=$hclen\n";

					# Determine the code length huffman code
					my @alpha_code = (0) x @alpha_map;
					$alpha_code[$alpha_map[$_]] = b(3) for 0..$hclen-1;
					my $alpha_code = make_huffman(\@alpha_code);

					# Get lit/length and distance tables
					my @code_len;
					while (@code_len < $hlit+$hdist) {
						my $alpha = h($alpha_code);
						if ($alpha < 16) {
							push @code_len, $alpha;
						} elsif ($alpha == 16) {
							push @code_len, ($code_len[-1]) x (3+b(2));
						} elsif ($alpha == 17) {
							push @code_len, (0) x (3+b(3));
						} else {
							push @code_len, (0) x (11+b(7));
						}
					}
					if(@code_len != $hlit+$hdist) {
						return(1,"too many codes");
					}
					my @lit_len = splice(@code_len, 0, $hlit);
					$lit_code  = make_huffman(\@lit_len);
					$dist_code = make_huffman(\@code_len);
				} else {
					return(1,"deflate subtype $type not supported");
				}
				while (1) {
					my $lit = h($lit_code);
					if ($lit < 256) {
						$result .= chr($lit);
						$crc32 = $crc32>>8 ^ $crc32[$crc32&0xff^$lit];
					} else {
						if ($lit_extra[$lit -= 256] < 0) {
							if($lit) {
								return(1,"Invalid literal code");
							}
							last;
						}
						my $length = $lit_base[$lit] + 
							($lit_extra[$lit] && b($lit_extra[$lit]));

						my $d = h($dist_code);
						die "Invalid distance code" if $d >= 30;
						my $dist = $dist_base[$d] + 
							($dist_extra[$d] && b($dist_extra[$d]));
						$crc32 = $crc32>>8 ^ $crc32[$crc32&0xff^ord(substr($result .= substr($result, -$dist, 1), -1, 1))] for 1..$length;
					}
					$isize = ($isize + 32768) % 2**32, print $fout substr($result, 0, 32768, "") while
						length($result) >= 65536;
				}
			} else {
				# Not compressed;
				$bits_val = $bits_have = 0;
				my ($len, $nlen) = unpack("vv", r(4));
				if($len != (~$nlen & 0xffff)) {
					return(1,"$len is not the 1-complement of $nlen");
				}
				$result .= r($len);
				$crc32 = $crc32>>8 ^ $crc32[$crc32&0xff^ord(substr($result, $_, 1))] for -$len..-1;
				$isize = ($isize + 32768) % 2**32, print $fout substr($result, 0, 32768, "") while
					length($result) >= 65536;
			}
		} until $final;

		$crc32 ^= 0xffffffff;
		$isize = ($isize + length($result)) % 2**32;
		print $fout $result;
		if(!close($fout)) {
			return(1,"Error closing output handle: $!");
		}

		my ($wanted_crc32, $wanted_isize) = unpack("VV", r(8));
		#print STDERR "crc32=$crc32, wanted_crc32=$wanted_crc32, isize=$isize, wanted_isize=$wanted_isize\n";
		if($crc32 != $wanted_crc32) {
			return(1,"CRC32=$crc32, expected $wanted_crc32");
		}
		if($isize != $wanted_isize) {
			return(1,"element size=$isize, expected $wanted_isize");
		}
	}
}
###gunzip end

__DATA__
11C Opcode Start
#  op | code               | display  |
#-----+--------------------+----------+
   00 | LBL 0              | 42,21, 0 |
   01 | LBL 1              | 42,21, 1 |
   02 | LBL 2              | 42,21, 2 |
   03 | LBL 3              | 42,21, 3 |
   04 | LBL 4              | 42,21, 4 |
   05 | LBL 5              | 42,21, 5 |
   06 | LBL 6              | 42,21, 6 |
   07 | LBL 7              | 42,21, 7 |
   08 | LBL 8              | 42,21, 8 |
   09 | LBL 9              | 42,21, 9 |
   0a | LBL A              | 42,21,11 |
   0b | LBL B              | 42,21,12 |
   0c | LBL C              | 42,21,13 |
   0d | LBL D              | 42,21,14 |
   0e | LBL E              | 42,21,15 |
#  0f | spare              | 42,21,25 |
   10 | GTO 0              |    22  0 |
   11 | GTO 1              |    22  1 |
   12 | GTO 2              |    22  2 |
   13 | GTO 3              |    22  3 |
   14 | GTO 4              |    22  4 |
   15 | GTO 5              |    22  5 |
   16 | GTO 6              |    22  6 |
   17 | GTO 7              |    22  7 |
   18 | GTO 8              |    22  8 |
   19 | GTO 9              |    22  9 |
   1a | GTO A              |    22 11 |
   1b | GTO B              |    22 12 |
   1c | GTO C              |    22 13 |
   1d | GTO D              |    22 14 |
   1e | GTO E              |    22 15 |
   1f | GTO I              |    22 25 |
   20 | GSB 0              |    32  0 |
   21 | GSB 1              |    32  1 |
   22 | GSB 2              |    32  2 |
   23 | GSB 3              |    32  3 |
   24 | GSB 4              |    32  4 |
   25 | GSB 5              |    32  5 |
   26 | GSB 6              |    32  6 |
   27 | GSB 7              |    32  7 |
   28 | GSB 8              |    32  8 |
   29 | GSB 9              |    32  9 |
   2a | GSB A              |    32 11 |
   2b | GSB B              |    32 12 |
   2c | GSB C              |    32 13 |
   2d | GSB D              |    32 14 |
   2e | GSB E              |    32 15 |
   2f | GSB I              |    32 25 |
   30 | SCI 0              | 42, 8, 0 |
   31 | SCI 1              | 42, 8, 1 |
   32 | SCI 2              | 42, 8, 2 |
   33 | SCI 3              | 42, 8, 3 |
   34 | SCI 4              | 42, 8, 4 |
   35 | SCI 5              | 42, 8, 5 |
   36 | SCI 6              | 42, 8, 6 |
   37 | SCI 7              | 42, 8, 7 |
   38 | SF 0               | 43, 4, 0 |
   39 | SF 1               | 43, 4, 1 |
   3a | STO+ 0             | 44,40, 0 |
   3b | STO+ 1             | 44,40, 1 |
   3c | STO+ 2             | 44,40, 2 |
   3d | STO+ 3             | 44,40, 3 |
   3e | STO+ 4             | 44,40, 4 |
   3f | RCL I              |    45 25 |
   40 | ENG 0              | 42, 9, 0 |
   41 | ENG 1              | 42, 9, 1 |
   42 | ENG 2              | 42, 9, 2 |
   43 | ENG 3              | 42, 9, 3 |
   44 | ENG 4              | 42, 9, 4 |
   45 | ENG 5              | 42, 9, 5 |
   46 | ENG 6              | 42, 9, 6 |
   47 | ENG 7              | 42, 9, 7 |
   48 | CF 0               | 43, 5, 0 |
   49 | CF 1               | 43, 5, 1 |
   4a | STO+ 5             | 44,40, 5 |
   4b | STO+ 6             | 44,40, 6 |
   4c | STO+ 7             | 44,40, 7 |
   4d | STO+ 8             | 44,40, 8 |
   4e | STO+ 9             | 44,40, 9 |
   4f | STO+ (i)           | 44,40,24 |
   50 | RCL 0              |    45  0 |
   51 | RCL 1              |    45  1 |
   52 | RCL 2              |    45  2 |
   53 | RCL 3              |    45  3 |
   54 | RCL 4              |    45  4 |
   55 | RCL 5              |    45  5 |
   56 | RCL 6              |    45  6 |
   57 | RCL 7              |    45  7 |
   58 | RCL 8              |    45  8 |
   59 | RCL 9              |    45  9 |
   5a | STO- 0             | 44,30, 0 |
   5b | STO- 1             | 44,30, 1 |
   5c | STO- 2             | 44,30, 2 |
   5d | STO- 3             | 44,30, 3 |
   5e | STO- 4             | 44,30, 3 |
   5f | RCL (i)            |    45 24 |
   60 | RCL .0             |    45 .0 |
   61 | RCL .1             |    45 .1 |
   62 | RCL .2             |    45 .2 |
   63 | RCL .3             |    45 .3 |
   64 | RCL .4             |    45 .4 |
   65 | RCL .5             |    45 .5 |
   66 | RCL .6             |    45 .6 |
   67 | RCL .7             |    45 .7 |
   68 | RCL .8             |    45 .8 |
   69 | RCL .9             |    45 .9 |
   6a | STO- 5             | 44,30, 5 |
   6b | STO- 6             | 44,30, 6 |
   6c | STO- 7             | 44,30, 7 |
   6d | STO- 8             | 44,30, 8 |
   6e | STO- 9             | 44,30, 9 |
   6f | STO- (i)           | 44,30,24 |
   70 | STO 0              |    44  0 |
   71 | STO 1              |    44  1 |
   72 | STO 2              |    44  2 |
   73 | STO 3              |    44  3 |
   74 | STO 4              |    44  4 |
   75 | STO 5              |    44  5 |
   76 | STO 6              |    44  6 |
   77 | STO 7              |    44  7 |
   78 | STO 8              |    44  8 |
   79 | STO 9              |    44  9 |
   7a | STOx 0             | 44,20, 0 |
   7a | STO* 0             | 44,20, 0 |
   7b | STOx 1             | 44,20, 1 |
   7b | STO* 1             | 44,20, 1 |
   7c | STOx 2             | 44,20, 2 |
   7c | STO* 2             | 44,20, 2 |
   7d | STOx 3             | 44,20, 3 |
   7d | STO* 3             | 44,20, 3 |
   7e | STOx 4             | 44,20, 3 |
   7e | STO* 4             | 44,20, 3 |
   7f | STO (i)            |    44 24 |
   80 | STO .0             |    44 .0 |
   81 | STO .1             |    44 .1 |
   82 | STO .2             |    44 .2 |
   83 | STO .3             |    44 .3 |
   84 | STO .4             |    44 .4 |
   85 | STO .5             |    44 .5 |
   86 | STO .6             |    44 .6 |
   87 | STO .7             |    44 .7 |
   88 | STO .8             |    44 .8 |
   89 | STO .9             |    44 .9 |
   8a | STOx 5             | 44,20, 5 |
   8a | STO* 5             | 44,20, 5 |
   8b | STOx 6             | 44,20, 6 |
   8b | STO* 6             | 44,20, 6 |
   8c | STOx 7             | 44,20, 7 |
   8c | STO* 7             | 44,20, 7 |
   8d | STOx 8             | 44,20, 8 |
   8d | STO* 8             | 44,20, 8 |
   8e | STOx 9             | 44,20, 9 |
   8e | STO* 9             | 44,20, 9 |
   8f | STOx (i)           | 44,20,24 |
   8f | STO* (i)           | 44,20,24 |
   90 | FIX 0              | 42, 7, 0 |
   91 | FIX 1              | 42, 7, 1 |
   92 | FIX 2              | 42, 7, 2 |
   93 | FIX 3              | 42, 7, 3 |
   94 | FIX 4              | 42, 7, 4 |
   95 | FIX 5              | 42, 7, 5 |
   96 | FIX 6              | 42, 7, 6 |
   97 | FIX 7              | 42, 7, 7 |
   98 | FIX 8              | 42, 7, 8 |
   99 | FIX 9              | 42, 7, 9 |
   9a | STO/ 0             | 44,40, 0 |
   9b | STO/ 1             | 44,10, 1 |
   9c | STO/ 2             | 44,10, 2 |
   9d | STO/ 3             | 44,10, 3 |
   9e | STO/ 4             | 44,10, 4 |
   9f | STO I              |    44 25 |
   a0 | SINH               | 42,22,23 |
   a1 | ASINH              | 43,22,23 |
   a1 | SINH^-1            | 43,22,23 |
   a2 | COSH               | 42,22,24 |
   a3 | ACOSH              | 43,22,24 |
   a3 | COSH^-1            | 43,22,24 |
   a4 | TANH               | 42,22,25 |
   a5 | ATANH              | 43,22,25 |
   a5 | TANH^-1            | 43,22,25 |
   a6 | RCL SIGMA+         |    45 49 |
   a6 | RCL S+             |    45 49 |
   a7 | STO RAN#           |    44 36 |
   a8 | F? 0               | 43, 6, 0 |
   a9 | F? 1               | 43, 6, 1 |
   aa | STO/ 5             | 44,10, 5 |
   ab | STO/ 6             | 44,10, 6 |
   ac | STO/ 7             | 44,10, 7 |
   ad | STO/ 8             | 44,10, 8 |
   ae | STO/ 9             | 44,10, 9 |
   af | STO/ (i)           | 44,10,24 |
   b0 | PSE                |    42 31 |
   b1 | CLEAR SIGMA        |    42 32 |
   b1 | CLR SIGMA          |    42 32 |
   b1 | CLR S              |    42 32 |
   b2 | CLEAR REG          |    42 34 |
   b2 | CLR REG            |    42 34 |
   b3 | RTN                |    43 32 |
   b4 | PI                 |    42 16 |
   b5 | RND                |    43 34 |
   b6 | LSTx               |    43 36 |
   b6 | LASTx              |    43 36 |
   b7 | ASIN               |    43 23 |
   b7 | SIN^-1             |    43 23 |
   b8 | ACOS               |    43 24 |
   b8 | COS^-1             |    43 24 |
   b9 | ATAN               |    43 25 |
   b9 | TAN^-1             |    43 25 |
   ba | x^2                |    43 11 |
   bb | LN                 |    43 12 |
   bc | LOG                |    43 13 |
   bd | %                  |    43 14 |
   be | DELTA %            |    43 15 |
   be | D%                 |    43 15 |
   bf | ->P                |    43 26 |
   c0 | R/S                |       31 |
   c0 | RUN                |       31 |
   c0 | START              |       31 |
   c0 | STOP               |       31 |
   c1 | Rv                 |       33 |
   c1 | R-v                |       33 |
   c1 | RDN                |       33 |
   c1 | ROLL DOWN          |       33 |
   c2 | x<>y               |       34 |
   c2 | x<->y              |       34 |
   c2 | SWAP               |       34 |
   c3 | CLx                |    43 35 |
   c4 | CHS                |       16 |
   c4 | +/-                |       16 |
   c5 | EEX                |       26 |
   c6 | ENTER              |       36 |
   c6 | ENTER^             |       36 |
   c7 | SIN                |       23 |
   c8 | COS                |       24 |
   c9 | TAN                |       25 |
   ca | SQRT               |       11 |
   ca | SQRT x             |       11 |
   cb | e^x                |       12 |
   cc | 10^x               |       13 |
   cd | y^x                |       14 |
   ce | 1/x                |       15 |
   cf | ->R                |    42 26 |
   d0 | x bar              |    43  0 |
   d0 | x_                 |    43  0 |
   d0 | MEAN               |    43  0 |
   d1 | Cy,x               |    43  1 |
   d2 | ->H                |    43  2 |
   d3 | ->DEG              |    43  3 |
   d4 | x<>(i)             |    42 23 |
   d4 | x<->(i)            |    42 23 |
   d5 | R^                 |    43 33 |
   d5 | R-^                |    43 33 |
   d5 | RUP                |    43 33 |
   d5 | ROLL UP            |    43 33 |
   d6 | RAN#               |    42 36 |
   d7 | DEG                |    43  7 |
   d8 | RAD                |    43  8 |
   d9 | GRAD               |    43  9 |
   da | x=0                |    43 40 |
   da | x=0?               |    43 40 |
   da | x==0               |    43 40 |
   da | x==0?              |    43 40 |
   db | x!=0               |    43 30 |
   db | x!=0?              |    43 30 |
   db | x#0                |    43 30 |
   db | x#0?               |    43 30 |
   db | x=/=0              |    43 30 |
   db | x=/=0?             |    43 30 |
   dc | x>0                |    43 20 |
   dc | x>0?               |    43 20 |
   dd | x<0                |    43 10 |
   dd | x<0?               |    43 10 |
   de | SIGMA-             |    43 49 |
   de | S-                 |    43 49 |
   df | s                  |    43 48 |
   df | STD DEV            |    43 48 |
   e0 | x!                 |    42  0 |
   e0 | n!                 |    42  0 |
   e0 | FACT               |    42  0 |
   e1 | Py,x               |    42  1 |
   e2 | ->H.MS             |    42  2 |
   e3 | ->RAD              |    42  3 |
   e4 | x<>I               |    42  4 |
   e4 | x<->I              |    42  4 |
   e5 | DSE                |    42  5 |
   e6 | ISG                |    42  6 |
   e7 | INT                |    43 44 |
   e8 | FRAC               |    42 44 |
   e9 | ABS                |    43 16 |
   ea | x=y                |    42 40 |
   ea | x=y?               |    42 40 |
   ea | x==y               |    42 40 |
   ea | x==y?              |    42 40 |
   eb | x!=y               |    42 30 |
   eb | x!=y?              |    42 30 |
   eb | x#y                |    42 30 |
   eb | x#y?               |    42 30 |
   eb | x=/=y              |    42 30 |
   eb | x=/=y?             |    42 30 |
   ec | x>y                |    42 20 |
   ec | x>y?               |    42 20 |
   ed | x<=y               |    42 10 |
   ed | x<=y?              |    42 10 |
   ee | L.R.               |    42 49 |
   ef | y^,r               |    42 48 |
   ef | y hat, r           |    42 48 |
   ef | LIN EST            |    42 48 |
   f0 | 0                  |        0 |
   f1 | 1                  |        1 |
   f2 | 2                  |        2 |
   f3 | 3                  |        3 |
   f4 | 4                  |        4 |
   f5 | 5                  |        5 |
   f6 | 6                  |        6 |
   f7 | 7                  |        7 |
   f8 | 8                  |        8 |
   f9 | 9                  |        9 |
   fa | +                  |       40 |
   fb | -                  |       30 |
   fc | x                  |       20 |
   fc | *                  |       20 |
   fd | /                  |       10 |
   fe | SIGMA+             |       49 |
   fe | S+                 |       49 |
   ff | .                  |       48 |
11C Opcode End

11C Macro Start
&SMOD
LBL 9
-
LSTx
x<=y
GTO 9
Rv
&MOD
x<>y
ENTER
Rv
x<>y
/
LSTx
x<>y
INT
*
R^
-
CHS
11C Macro End

11C New Start
<?xml version="1.0" encoding="ISO-8859-1"?>
<!DOCTYPE state SYSTEM "nonpareil.dtd">
<state version="1.00" model="11C" platform="voyager" arch="nut">
<ui/>
<chip name="Nut">
<registers>
<reg name="a" data="00000000000000"/>
<reg name="b" data="00000000000000"/>
<reg name="c" data="00000000000eae"/>
<reg name="m" data="00000000000000"/>
<reg name="n" data="00000000000000"/>
<reg name="g" data="09"/>
<reg name="p" data="c"/>
<reg name="q" data="3"/>
<reg name="q_sel" data="0"/>
<reg name="fo" data="00"/>
<reg name="s" data="0800"/>
<reg name="pc" data="0000"/>
<reg name="stack" index="0" data="0089"/>
<reg name="stack" index="1" data="0042"/>
<reg name="stack" index="2" data="0000"/>
<reg name="stack" index="3" data="0000"/>
<reg name="decimal" data="0"/>
<reg name="carry" data="0"/>
<reg name="awake" data="0"/>
<reg name="pf_addr" data="00"/>
<reg name="ram_addr" data="007"/>
<reg name="active_bank" index="0" data="0"/>
<reg name="active_bank" index="1" data="0"/>
<reg name="active_bank" index="2" data="0"/>
<reg name="active_bank" index="3" data="0"/>
<reg name="active_bank" index="4" data="0"/>
<reg name="active_bank" index="5" data="0"/>
<reg name="active_bank" index="6" data="0"/>
<reg name="active_bank" index="7" data="0"/>
<reg name="active_bank" index="8" data="0"/>
<reg name="active_bank" index="9" data="0"/>
<reg name="active_bank" index="a" data="0"/>
<reg name="active_bank" index="b" data="0"/>
<reg name="active_bank" index="c" data="0"/>
<reg name="active_bank" index="d" data="0"/>
<reg name="active_bank" index="e" data="0"/>
<reg name="active_bank" index="f" data="0"/>
</registers>
</chip>
<chip name="Voyager LCD">
<registers>
<reg name="enable" data="1"/>
<reg name="blink" data="0"/>
</registers>
</chip>
<memory as="ram">
<loc addr="000" data="00000000000000"/>
<loc addr="001" data="00000000000000"/>
<loc addr="002" data="00000000000000"/>
<loc addr="003" data="00000000000000"/>
<loc addr="004" data="00000000000000"/>
<loc addr="005" data="00000000000008"/>
<loc addr="006" data="0000000000000c"/>
<loc addr="007" data="00000000000eae"/>
<loc addr="008" data="00000000000000"/>
<loc addr="009" data="2faf8befbe2280"/>
<loc addr="00a" data="bef282bcbcaf80"/>
<loc addr="0e0" data="00000000000000"/>
<loc addr="0e1" data="00000000000000"/>
<loc addr="0e2" data="00000000000000"/>
<loc addr="0e3" data="00000000000000"/>
<loc addr="0e4" data="00000000000000"/>
<loc addr="0e5" data="00000000000000"/>
<loc addr="0e6" data="00000000000000"/>
<loc addr="0e7" data="00000000000000"/>
<loc addr="0e8" data="00000000000000"/>
<loc addr="0e9" data="00000000000000"/>
<loc addr="0ea" data="00000000000000"/>
<loc addr="0eb" data="00000000000000"/>
<loc addr="0ec" data="00000000000000"/>
<loc addr="0ed" data="00000000000000"/>
<loc addr="0ee" data="00000000000000"/>
<loc addr="0ef" data="00000000000000"/>
<loc addr="0f0" data="00000000000000"/>
<loc addr="0f1" data="00000000000000"/>
<loc addr="0f2" data="00000000000000"/>
<loc addr="0f3" data="00000000000000"/>
<loc addr="0f4" data="00000000000000"/>
<loc addr="0f5" data="00000000000000"/>
<loc addr="0f6" data="00000000000000"/>
<loc addr="0f7" data="00000000000000"/>
<loc addr="0f8" data="00000000000000"/>
<loc addr="0f9" data="00000000000000"/>
<loc addr="0fa" data="00000000000000"/>
<loc addr="0fb" data="00000000000000"/>
<loc addr="0fc" data="00000000000000"/>
<loc addr="0fd" data="00000000000000"/>
<loc addr="0fe" data="00000000000000"/>
<loc addr="0ff" data="00000000000000"/>
</memory>
</state>
11C New End

12C Opcode Start
#  op | code               | display  |
#-----+--------------------+----------+
   00 | GTO 00             | 43,33 00 |
   00 | RTN                | 43,33 00 |
   01 | GTO 01             | 43,33 01 |
   02 | GTO 02             | 43,33 02 |
   03 | GTO 03             | 43,33 03 |
   04 | GTO 04             | 43,33 04 |
   05 | GTO 05             | 43,33 05 |
   06 | GTO 06             | 43,33 06 |
   07 | GTO 07             | 43,33 07 |
   08 | GTO 08             | 43,33 08 |
   09 | GTO 09             | 43,33 09 |
   0a | STO .0             | 44 48  0 |
   0b | RCL .0             | 45 48  0 |
   0c | STO 0              |    44  0 |
   0d | RCL 0              |    45  0 |
   0e | f0                 |    42  0 |
   0e | FIX 0              |    42  0 |
   0f | 0                  |        0 |
   10 | GTO 10             | 43,33 10 |
   11 | GTO 11             | 43,33 11 |
   12 | GTO 12             | 43,33 12 |
   13 | GTO 13             | 43,33 13 |
   14 | GTO 14             | 43,33 14 |
   15 | GTO 15             | 43,33 15 |
   16 | GTO 16             | 43,33 16 |
   17 | GTO 17             | 43,33 17 |
   18 | GTO 18             | 43,33 18 |
   19 | GTO 19             | 43,33 19 |
   1a | STO .1             | 44 48  1 |
   1b | RCL .1             | 45 48  1 |
   1c | STO 1              |    44  1 |
   1d | RCL 1              |    45  1 |
   1e | f1                 |    42  1 |
   1e | FIX 1              |    42  1 |
   1f | 1                  |        1 |
   20 | GTO 20             | 43,33 20 |
   21 | GTO 21             | 43,33 21 |
   22 | GTO 22             | 43,33 22 |
   23 | GTO 23             | 43,33 23 |
   24 | GTO 24             | 43,33 24 |
   25 | GTO 25             | 43,33 25 |
   26 | GTO 26             | 43,33 26 |
   27 | GTO 27             | 43,33 27 |
   28 | GTO 28             | 43,33 28 |
   29 | GTO 29             | 43,33 29 |
   2a | STO .2             | 44 48  2 |
   2b | RCL .2             | 45 48  2 |
   2c | STO 2              |    44  2 |
   2d | RCL 2              |    45  2 |
   2e | f2                 |    42  2 |
   2e | FIX 2              |    42  2 |
   2f | 2                  |        2 |
   30 | GTO 30             | 43,33 30 |
   31 | GTO 31             | 43,33 31 |
   32 | GTO 32             | 43,33 32 |
   33 | GTO 33             | 43,33 33 |
   34 | GTO 34             | 43,33 34 |
   35 | GTO 35             | 43,33 35 |
   36 | GTO 36             | 43,33 36 |
   37 | GTO 37             | 43,33 37 |
   38 | GTO 38             | 43,33 38 |
   39 | GTO 39             | 43,33 39 |
   3a | STO .3             | 44 48  3 |
   3b | RCL .3             | 45 48  3 |
   3c | STO 3              |    44  3 |
   3d | RCL 3              |    45  3 |
   3e | f3                 |    42  3 |
   3e | FIX 3              |    42  3 |
   3f | 3                  |        3 |
   40 | GTO 40             | 43,33 40 |
   41 | GTO 41             | 43,33 41 |
   42 | GTO 42             | 43,33 42 |
   43 | GTO 43             | 43,33 43 |
   44 | GTO 44             | 43,33 44 |
   45 | GTO 45             | 43,33 45 |
   46 | GTO 46             | 43,33 46 |
   47 | GTO 47             | 43,33 47 |
   48 | GTO 48             | 43,33 48 |
   49 | GTO 49             | 43,33 49 |
   4a | STO .4             | 44 48  4 |
   4b | RCL .4             | 45 48  4 |
   4c | STO 4              |    44  4 |
   4d | RCL 4              |    45  4 |
   4e | f4                 |    42  4 |
   4e | FIX 4              |    42  4 |
   4f | 4                  |        4 |
   50 | GTO 50             | 43,33 50 |
   51 | GTO 51             | 43,33 51 |
   52 | GTO 52             | 43,33 52 |
   53 | GTO 53             | 43,33 53 |
   54 | GTO 54             | 43,33 54 |
   55 | GTO 55             | 43,33 55 |
   56 | GTO 56             | 43,33 56 |
   57 | GTO 57             | 43,33 57 |
   58 | GTO 58             | 43,33 58 |
   59 | GTO 59             | 43,33 59 |
   5a | STO .5             | 44 48  5 |
   5b | RCL .5             | 45 48  5 |
   5c | STO 5              |    44  5 |
   5d | RCL 5              |    45  5 |
   5e | f5                 |    42  5 |
   5e | FIX 5              |    42  5 |
   5f | 5                  |        5 |
   60 | GTO 60             | 43,33 60 |
   61 | GTO 61             | 43,33 61 |
   62 | GTO 62             | 43,33 62 |
   63 | GTO 63             | 43,33 63 |
   64 | GTO 64             | 43,33 64 |
   65 | GTO 65             | 43,33 65 |
   66 | GTO 66             | 43,33 66 |
   67 | GTO 67             | 43,33 67 |
   68 | GTO 68             | 43,33 68 |
   69 | GTO 69             | 43,33 69 |
   6a | STO .6             | 44 48  6 |
   6b | RCL .6             | 45 48  6 |
   6c | STO 6              |    44  6 |
   6d | RCL 6              |    45  6 |
   6e | f6                 |    42  6 |
   6e | FIX 6              |    42  6 |
   6f | 6                  |        6 |
   70 | GTO 70             | 43,33 70 |
   71 | GTO 71             | 43,33 71 |
   72 | GTO 72             | 43,33 72 |
   73 | GTO 73             | 43,33 73 |
   74 | GTO 74             | 43,33 74 |
   75 | GTO 75             | 43,33 75 |
   76 | GTO 76             | 43,33 76 |
   77 | GTO 77             | 43,33 77 |
   78 | GTO 78             | 43,33 78 |
   79 | GTO 79             | 43,33 79 |
   7a | STO .7             | 44 48  7 |
   7b | RCL .7             | 45 48  7 |
   7c | STO 7              |    44  7 |
   7d | RCL 7              |    45  7 |
   7e | f7                 |    42  7 |
   7e | FIX 7              |    42  7 |
   7f | 7                  |        7 |
   80 | GTO 80             | 43,33 80 |
   81 | GTO 81             | 43,33 81 |
   82 | GTO 82             | 43,33 82 |
   83 | GTO 83             | 43,33 83 |
   84 | GTO 84             | 43,33 84 |
   85 | GTO 85             | 43,33 85 |
   86 | GTO 86             | 43,33 86 |
   87 | GTO 87             | 43,33 87 |
   88 | GTO 88             | 43,33 88 |
   89 | GTO 89             | 43,33 89 |
   8a | STO .8             | 44 48  8 |
   8b | RCL .8             | 45 48  8 |
   8c | STO 8              |    44  8 |
   8d | RCL 8              |    45  8 |
   8e | f8                 |    42  8 |
   8e | FIX 8              |    42  8 |
   8f | 8                  |        8 |
   90 | GTO 90             | 43,33 90 |
   91 | GTO 91             | 43,33 91 |
   92 | GTO 92             | 43,33 92 |
   93 | GTO 93             | 43,33 93 |
   94 | GTO 94             | 43,33 94 |
   95 | GTO 95             | 43,33 95 |
   96 | GTO 96             | 43,33 96 |
   97 | GTO 97             | 43,33 97 |
   98 | GTO 98             | 43,33 98 |
   99 | GTO 99             | 43,33 99 |
   9a | STO .9             | 44 48  9 |
   9b | RCL .9             | 45 48  9 |
   9c | STO 9              |    44  9 |
   9d | RCL 9              |    45  9 |
   9e | f9                 |    42  9 |
   9e | FIX 9              |    42  9 |
   9f | 9                  |        9 |
   a0 | .                  |       48 |
   a1 | EEX                |       26 |
   a2 | CHS                |       16 |
   a2 | +/-                |       16 |
   a3 | R/S                |       31 |
   a4 | CLx                |       35 |
   a5 | x<>y               |       34 |
   a5 | SWAP               |       34 |
   a6 | n                  |       11 |
   a7 | i                  |       12 |
   a8 | PV                 |       13 |
   a9 | PMT                |       14 |
   aa | FV                 |       15 |
   ab | y^x                |       21 |
   ac | 1/x                |       22 |
   ad | %T                 |       23 |
   ae | DELTA %            |       24 |
   ae | D%                 |       24 |
   af | %                  |       25 |
   b0 | f.                 |    42 48 |
   b0 | FIX .              |    42 48 |
   b1 | x                  |       20 |
   b1 | *                  |       20 |
   b2 | -                  |       30 |
   b3 | /                  |       10 |
   b4 | +                  |       40 |
   b5 | CLEAR FIN          |    42 34 |
   b5 | CLR FIN            |    42 34 |
   b6 | AMORT              |    42 11 |
   b7 | INT                |    42 12 |
   b8 | NPV                |    42 13 |
   b9 | RND                |    42 14 |
   ba | IRR                |    42 15 |
   bb | PRICE              |    42 21 |
   bc | YTM                |    42 22 |
   bd | SL                 |    42 23 |
   be | SOYD               |    42 24 |
   bf | DB                 |    42 25 |
   c0 | s                  |    43 48 |
   c0 | STD DEV            |    43 48 |
   c1 | DELTA DAYS         |    43 26 |
   c1 | DDAYS              |    43 26 |
   c1 | DDYS               |    43 26 |
   c1 | DYS                |    43 26 |
   c2 | DATE               |    43 16 |
   c3 | PSE                |    43 31 |
   c4 | x=0                |    43 35 |
   c4 | x=0?               |    43 35 |
   c4 | x==0               |    43 35 |
   c4 | x==0?              |    43 35 |
   c5 | x<=y               |    43 34 |
   c5 | x<=y?              |    43 34 |
   c6 | 12x                |    43 11 |
   c7 | 12/                |    43 12 |
   c8 | CFo                |    43 13 |
   c8 | CF0                |    43 13 |
   c9 | CFi                |    43 14 |
   ca | Ni                 |    43 15 |
   cb | SQRT               |    43 21 |
   cb | SQRT x             |    43 21 |
   cc | e^x                |    43 22 |
   cd | LN                 |    43 23 |
   ce | FRAC               |    43 24 |
   cf | INTG               |    43 25 |
   d0 | x bar              |    43  0 |
   d0 | x_                 |    43  0 |
   d0 | MEAN               |    43  0 |
   d1 | x^,r               |    43  1 |
   d1 | x har,r            |    43  1 |
   d1 | x LIN EST          |    43  1 |
   d2 | y^,r               |    43  2 |
   d2 | y hat,r            |    43  2 |
   d2 | y LIN EST          |    43  2 |
   d3 | n!                 |    43  3 |
   d3 | x!                 |    43  3 |
   d4 | ENTER              |       36 |
   d4 | ENTER^             |       36 |
   d5 | LSTx               |    43 36 |
   d5 | LASTx              |    43 36 |
   d6 | x bar w            |    43  6 |
   d6 | x_w                |    43  6 |
   d6 | WEIGHTED MEAN      |    43  6 |
   d7 | BEGIN              |    43  7 |
   d8 | END                |    43  8 |
   d9 | RCL 12/            |    45 12 |
   da | RCL CFi            |    45 14 |
   db | RCL PSE            | 45,43 31 |
   db | RCL g R/S          | 45,43 31 |
   dc | Rv                 |       33 |
   dc | R-v                |       33 |
   dc | RDN                |       33 |
   dc | ROLL DOWN          |       33 |
   dd | CLEAR SIGMA        |    42 32 |
   dd | CLR SIGMA          |    42 32 |
   dd | CLR S              |    42 32 |
   de | RCL Ni             |    45 15 |
   df | RCL 12x            |    45 11 |
   e0 | SIGMA-             |       49 |
   e0 | S-                 |       49 |
   e1 | SIGMA+             |    43 49 |
   e1 | S+                 |    43 49 |
   e2 | RCL n              |    45 11 |
   e3 | RCL i              |    45 12 |
   e4 | RCL PV             |    45 13 |
   e5 | RCL PMT            |    45 14 |
   e6 | RCL FV             |    45 15 |
   e7 | STO n              |    44 11 |
   e8 | STO i              |    44 12 |
   e9 | STO PV             |    44 13 |
   ea | STO PMT            |    44 14 |
   eb | STO FV             |    44 15 |
   ec | STO+ 0             | 44 40  0 |
   ed | STO+ 1             | 44 40  1 |
   ee | STO+ 2             | 44 40  2 |
   ef | STO+ 3             | 44 40  3 |
   f0 | STO+ 4             | 44 40  4 |
   f1 | STO- 0             | 44 30  0 |
   f2 | STO- 1             | 44 30  1 |
   f3 | STO- 2             | 44 30  2 |
   f4 | STO- 3             | 44 30  3 |
   f5 | STO- 4             | 44 30  4 |
   f6 | STOx 0             | 44 20  0 |
   f6 | STO* 0             | 44 20  0 |
   f7 | STOx 1             | 44 20  1 |
   f7 | STO* 1             | 44 20  1 |
   f8 | STOx 2             | 44 20  2 |
   f8 | STO* 2             | 44 20  2 |
   f9 | STOx 3             | 44 20  3 |
   f9 | STO* 3             | 44 20  3 |
   fa | STOx 4             | 44 20  4 |
   fa | STO* 4             | 44 20  4 |
   fb | STO/ 0             | 44 10  0 |
   fc | STO/ 1             | 44 10  1 |
   fd | STO/ 2             | 44 10  2 |
   fe | STO/ 3             | 44 10  3 |
   ff | STO/ 4             | 44 10  4 |
12C Opcode End

12C Macro Start
&SMOD
LBL START
-
LSTx
x<=y
GTO START
Rv
&MOD
x<>y
ENTER
Rv
x<>y
/
LSTx
x<>y
INTG
*
x<>y
-
CHS
12C Macro End

12C New Start
<?xml version="1.0" encoding="ISO-8859-1"?>
<!DOCTYPE state SYSTEM "nonpareil.dtd">
<state version="1.00" model="12C" platform="voyager" arch="nut">
<ui/>
<chip name="Nut">
<registers>
<reg name="a" data="00000000000000"/>
<reg name="b" data="00000000000000"/>
<reg name="c" data="ffffffffffffff"/>
<reg name="m" data="00000000000000"/>
<reg name="n" data="00000000000000"/>
<reg name="g" data="49"/>
<reg name="p" data="c"/>
<reg name="q" data="1"/>
<reg name="q_sel" data="0"/>
<reg name="fo" data="00"/>
<reg name="s" data="0808"/>
<reg name="pc" data="0000"/>
<reg name="stack" index="0" data="0022"/>
<reg name="stack" index="1" data="0000"/>
<reg name="stack" index="2" data="0000"/>
<reg name="stack" index="3" data="0000"/>
<reg name="decimal" data="0"/>
<reg name="carry" data="0"/>
<reg name="awake" data="0"/>
<reg name="pf_addr" data="00"/>
<reg name="ram_addr" data="008"/>
<reg name="active_bank" index="0" data="0"/>
<reg name="active_bank" index="1" data="0"/>
<reg name="active_bank" index="2" data="0"/>
<reg name="active_bank" index="3" data="0"/>
<reg name="active_bank" index="4" data="0"/>
<reg name="active_bank" index="5" data="0"/>
<reg name="active_bank" index="6" data="0"/>
<reg name="active_bank" index="7" data="0"/>
<reg name="active_bank" index="8" data="0"/>
<reg name="active_bank" index="9" data="0"/>
<reg name="active_bank" index="a" data="0"/>
<reg name="active_bank" index="b" data="0"/>
<reg name="active_bank" index="c" data="0"/>
<reg name="active_bank" index="d" data="0"/>
<reg name="active_bank" index="e" data="0"/>
<reg name="active_bank" index="f" data="0"/>
</registers>
</chip>
<chip name="Voyager LCD">
<registers>
<reg name="enable" data="1"/>
<reg name="blink" data="0"/>
</registers>
</chip>
<memory as="ram">
<loc addr="000" data="00000000000000"/>
<loc addr="001" data="00000000000000"/>
<loc addr="002" data="00000000000000"/>
<loc addr="003" data="00000000000000"/>
<loc addr="004" data="00000000000000"/>
<loc addr="005" data="00000000000008"/>
<loc addr="006" data="0000000000000c"/>
<loc addr="007" data="00000000000000"/>
<loc addr="008" data="00000000000000"/>
<loc addr="009" data="2faf8befbe2280"/>
<loc addr="00a" data="bef282bcbcaf80"/>
<loc addr="0e0" data="00000000000000"/>
<loc addr="0e1" data="00000000000000"/>
<loc addr="0e2" data="00000000000000"/>
<loc addr="0e3" data="00000000000000"/>
<loc addr="0e4" data="00000000000000"/>
<loc addr="0e5" data="00000000000000"/>
<loc addr="0e6" data="00000000000000"/>
<loc addr="0e7" data="00000000000000"/>
<loc addr="0e8" data="00000000000000"/>
<loc addr="0e9" data="00000000000000"/>
<loc addr="0ea" data="00000000000000"/>
<loc addr="0eb" data="00000000000000"/>
<loc addr="0ec" data="00000000000000"/>
<loc addr="0ed" data="00000000000000"/>
<loc addr="0ee" data="00000000000000"/>
<loc addr="0ef" data="00000000000000"/>
<loc addr="0f0" data="00000000000000"/>
<loc addr="0f1" data="00000000000000"/>
<loc addr="0f2" data="00000000000000"/>
<loc addr="0f3" data="00000000000000"/>
<loc addr="0f4" data="00000000000000"/>
<loc addr="0f5" data="00000000000000"/>
<loc addr="0f6" data="00000000000000"/>
<loc addr="0f7" data="00000000000000"/>
<loc addr="0f8" data="00000000000000"/>
<loc addr="0f9" data="00000000000000"/>
<loc addr="0fa" data="00000000000000"/>
<loc addr="0fb" data="00000000000000"/>
<loc addr="0fc" data="00000000000000"/>
<loc addr="0fd" data="00000000000000"/>
<loc addr="0fe" data="00000000d85d00"/>
<loc addr="0ff" data="00000000000000"/>
</memory>
</state>
12C New End

15C Opcode Start
#  op | code               | display  |
#-----+--------------------+----------+
   00 | LBL 0              | 42,21, 0 |
   01 | LBL 1              | 42,21, 1 |
   02 | LBL 2              | 42,21, 2 |
   03 | LBL 3              | 42,21, 3 |
   04 | LBL 4              | 42,21, 4 |
   05 | LBL 5              | 42,21, 5 |
   06 | LBL 6              | 42,21, 6 |
   07 | LBL 7              | 42,21, 7 |
   08 | LBL 8              | 42,21, 8 |
   09 | LBL 9              | 42,21, 9 |
   0a | LBL A              | 42,21,11 |
   0b | LBL B              | 42,21,12 |
   0c | LBL C              | 42,21,13 |
   0d | LBL D              | 42,21,14 |
   0e | LBL E              | 42,21,15 |
   10 | GTO 0              |    22  0 |
   11 | GTO 1              |    22  1 |
   12 | GTO 2              |    22  2 |
   13 | GTO 3              |    22  3 |
   14 | GTO 4              |    22  4 |
   15 | GTO 5              |    22  5 |
   16 | GTO 6              |    22  6 |
   17 | GTO 7              |    22  7 |
   18 | GTO 8              |    22  8 |
   19 | GTO 9              |    22  9 |
   1a | GTO A              |    22 11 |
   1b | GTO B              |    22 12 |
   1c | GTO C              |    22 13 |
   1d | GTO D              |    22 14 |
   1e | GTO E              |    22 15 |
   20 | GSB 0              |    32  0 |
   21 | GSB 1              |    32  1 |
   22 | GSB 2              |    32  2 |
   23 | GSB 3              |    32  3 |
   24 | GSB 4              |    32  4 |
   25 | GSB 5              |    32  5 |
   26 | GSB 6              |    32  6 |
   27 | GSB 7              |    32  7 |
   28 | GSB 8              |    32  8 |
   29 | GSB 9              |    32  9 |
   2a | GSB A              |    32 11 |
   2b | GSB B              |    32 12 |
   2c | GSB C              |    32 13 |
   2d | GSB D              |    32 14 |
   2e | GSB E              |    32 15 |
   30 | RCL 0              |    45  0 |
   31 | RCL 1              |    45  1 |
   32 | RCL 2              |    45  2 |
   33 | RCL 3              |    45  3 |
   34 | RCL 4              |    45  4 |
   35 | RCL 5              |    45  5 |
   36 | RCL 6              |    45  6 |
   37 | RCL 7              |    45  7 |
   38 | RCL 8              |    45  8 |
   39 | RCL 9              |    45  9 |
   3a | RCL A              |    45 11 |
   3b | RCL B              |    45 12 |
   3c | RCL C              |    45 13 |
   3d | RCL D              |    45 14 |
   3e | RCL E              |    45 15 |
   40 | STO 0              |    44  0 |
   41 | STO 1              |    44  1 |
   42 | STO 2              |    44  2 |
   43 | STO 3              |    44  3 |
   44 | STO 4              |    44  4 |
   45 | STO 5              |    44  5 |
   46 | STO 6              |    44  6 |
   47 | STO 7              |    44  7 |
   48 | STO 8              |    44  8 |
   49 | STO 9              |    44  9 |
   4a | STO A              |    44 11 |
   4b | STO B              |    44 12 |
   4c | STO C              |    44 13 |
   4d | STO D              |    44 14 |
   4e | STO E              |    44 15 |
   50 | RCL .0             |    45 .0 |
   51 | RCL .1             |    45 .1 |
   52 | RCL .2             |    45 .2 |
   53 | RCL .3             |    45 .3 |
   54 | RCL .4             |    45 .4 |
   55 | RCL .5             |    45 .5 |
   56 | RCL .6             |    45 .6 |
   57 | RCL .7             |    45 .7 |
   58 | RCL .8             |    45 .8 |
   59 | RCL .9             |    45 .9 |
   5a | RCL g A            | 45,43,11 |
   5b | RCL g B            | 45,43,12 |
   5c | RCL g C            | 45,43,13 |
   5d | RCL g D            | 45,43,14 |
   5e | RCL g E            | 45,43,15 |
   60 | STO .0             |    44 .0 |
   61 | STO .1             |    44 .1 |
   62 | STO .2             |    44 .2 |
   63 | STO .3             |    44 .3 |
   64 | STO .4             |    44 .4 |
   65 | STO .5             |    44 .5 |
   66 | STO .6             |    44 .6 |
   67 | STO .7             |    44 .7 |
   68 | STO .8             |    44 .8 |
   69 | STO .9             |    44 .9 |
   6a | STO g A            | 44,43,11 |
   6b | STO g B            | 44,43,12 |
   6c | STO g C            | 44,43,13 |
   6d | STO g D            | 44,43,14 |
   6e | STO g E            | 44,43,15 |
   70 | TEST 0             | 43,30, 0 |
   70 | x!=0               | 43,30, 0 |
   70 | x!=0?              | 43,30, 0 |
   70 | x#0                | 43,30, 0 |
   70 | x#0?               | 43,30, 0 |
   70 | x=/=0              | 43,30, 0 |
   70 | x=/=0?             | 43,30, 0 |
   71 | TEST 1             | 43,30, 1 |
   71 | x>0                | 43,30, 1 |
   71 | x>0?               | 43,30, 1 |
   72 | TEST 2             | 43,30, 2 |
   72 | x<0                | 43,30, 2 |
   72 | x<0?               | 43,30, 2 |
   73 | TEST 3             | 43,30, 3 |
   73 | x>=0               | 43,30, 3 |
   73 | x>=0?              | 43,30, 3 |
   74 | TEST 4             | 43,30, 4 |
   74 | x<=0               | 43,30, 4 |
   74 | x<=0?              | 43,30, 4 |
   75 | TEST 5             | 43,30, 5 |
   75 | x=y                | 43,30, 5 |
   75 | x=y?               | 43,30, 5 |
   75 | x==y               | 43,30, 5 |
   75 | x==y?              | 43,30, 5 |
   76 | TEST 6             | 43,30, 6 |
   76 | x!=y               | 43,30, 6 |
   76 | x!=y?              | 43,30, 6 |
   76 | x#y                | 43,30, 6 |
   76 | x#y?               | 43,30, 6 |
   76 | x=/=y              | 43,30, 6 |
   76 | x=/=y?             | 43,30, 6 |
   77 | TEST 7             | 43,30, 7 |
   77 | x>y                | 43,30, 7 |
   77 | x>y?               | 43,30, 7 |
   78 | TEST 8             | 43,30, 8 |
   78 | x<y                | 43,30, 8 |
   78 | x<y?               | 43,30, 8 |
   79 | TEST 9             | 43,30, 9 |
   79 | x>=y               | 43,30, 9 |
   79 | x>=y?              | 43,30, 9 |
   7a | RCL MATRIX A       | 45,16,11 |
   7a | RCL MAT A          | 45,16,11 |
   7b | RCL MATRIX B       | 45,16,12 |
   7b | RCL MAT B          | 45,16,12 |
   7c | RCL MATRIX C       | 45,16,13 |
   7c | RCL MAT C          | 45,16,13 |
   7d | RCL MATRIX D       | 45,16,14 |
   7d | RCL MAT D          | 45,16,14 |
   7e | RCL MATRIX E       | 45,16,15 |
   7e | RCL MAT E          | 45,16,15 |
   80 | x<>0               | 42, 4, 0 |
   81 | x<>(i)             | 42, 4,24 |
   82 | DSE 0              | 42, 5, 0 |
   83 | DSE (i)            | 42, 5,24 |
   84 | ISG 0              | 42, 6, 0 |
   85 | ISG (i)            | 42, 6,24 |
   86 | RCL (i)            |    45 24 |
   87 | RCL I              |    45 25 |
   88 | GTO I              |    22 25 |
   89 | GSB I              |    32 25 |
   8a | RESULT A           | 42,26,11 |
   8a | RES A              | 42,26,11 |
   8b | RESULT B           | 42,26,12 |
   8b | RES B              | 42,26,12 |
   8c | RESULT C           | 42,26,13 |
   8c | RES C              | 42,26,13 |
   8d | RESULT D           | 42,26,14 |
   8d | RES D              | 42,26,14 |
   8e | RESULT E           | 42,26,15 |
   8e | RES E              | 42,26,15 |
   90 | x<>1               | 42, 4, 1 |
   91 | x<>I               | 42, 4,25 |
   92 | DSE 1              | 42, 5, 1 |
   93 | DSE I              | 42, 5,25 |
   94 | ISG 1              | 42, 6, 1 |
   95 | ISG I              | 42, 6,25 |
   96 | STO (i)            |    44 24 |
   97 | STO I              |    44 25 |
   98 | DIM (i)            | 42,23,24 |
   99 | DIM I              | 42,23,25 |
   9a | DIM A              | 42,23,11 |
   9b | DIM B              | 42,23,12 |
   9c | DIM C              | 42,23,13 |
   9d | DIM D              | 42,23,14 |
   9e | DIM E              | 42,23,15 |
   a0 | y^,r               |    42 48 |
   a0 | y hat,r            |    42 48 |
   a0 | LIN EST            |    42 48 |
   a1 | RAN#               |    42 36 |
   a2 | CLx                |    43 35 |
   a3 | FRAC               |    42 44 |
   a4 | I                  |    42 25 |
   a5 | CLEAR REG          |    42 34 |
   a5 | CLR REG            |    42 34 |
   a6 | STO RESULT         |    44 26 |
   a6 | STO RES            |    44 26 |
   a7 | RCL S              |    45 49 |
   a8 | RCL DIM (i)        | 45,23,24 |
   a9 | RCL DIM I          | 45,23,25 |
   aa | RCL DIM A          | 45,23,11 |
   ab | RCL DIM B          | 45,23,12 |
   ac | RCL DIM C          | 45,23,13 |
   ad | RCL DIM D          | 45,23,14 |
   ae | RCL DIM E          | 45,23,15 |
   b0 | s                  |    43 48 |
   b0 | STD DEV            |    43 48 |
   b1 | LSTx               |    43 36 |
   b1 | LASTx              |    43 36 |
   b2 | RTN                |    43 32 |
   b3 | ABS                |    43 16 |
   b4 | R^                 |    43 33 |
   b4 | R-^                |    43 33 |
   b4 | RUP                |    43 33 |
   b4 | ROLL UP            |    43 33 |
   b5 | RND                |    43 34 |
   b6 | PI                 |    43 26 |
   b7 | ASIN               |    43 23 |
   b7 | SIN^-1             |    43 23 |
   b8 | ACOS               |    43 24 |
   b8 | COS^-1             |    43 24 |
   b9 | ATAN               |    43 25 |
   b9 | TAN^-1             |    43 25 |
   ba | x^2                |    43 11 |
   bb | LN                 |    43 12 |
   bc | LOG                |    43 13 |
   bd | %                  |    43 14 |
   be | DELTA %            |    43 15 |
   be | D%                 |    43 15 |
   c0 | .                  |       48 |
   c1 | ENTER              |       36 |
   c1 | ENTER^             |       36 |
   c2 | R/S                |       31 |
   c2 | RUN                |       31 |
   c2 | START              |       31 |
   c2 | STOP               |       31 |
   c3 | CHS                |       16 |
   c3 | +/-                |       16 |
   c4 | Rv                 |       33 |
   c4 | R-v                |       33 |
   c4 | RDN                |       33 |
   c4 | ROLL DOWN          |       33 |
   c5 | x<>y               |       34 |
   c5 | SWAP               |       34 |
   c6 | EEX                |       26 |
   c7 | SIN                |       23 |
   c8 | COS                |       24 |
   c9 | TAN                |       25 |
   ca | SQRT               |       11 |
   ca | SQRT x             |       11 |
   cb | e^x                |       12 |
   cc | 10^x               |       13 |
   cd | y^x                |       14 |
   ce | 1/x                |       15 |
   d0 | x!                 |    42  0 |
   d0 | n!                 |    42  0 |
   d0 | FACT               |    42  0 |
   d1 | ->R                |    42  1 |
   d2 | ->H.MS             |    42  2 |
   d3 | ->RAD              |    42  3 |
   d4 | SINH               | 42,22,23 |
   d4 | HYP SIN            | 42,22,23 |
   d5 | COSH               | 42,22,24 |
   d5 | HYP COS            | 42,22,24 |
   d6 | TANH               | 42,22,25 |
   d6 | HYP TAN            | 42,22,25 |
   d7 | RCL RESULT         |    45 26 |
   d7 | RCL RES            |    45 26 |
   d8 | RCL RAN#           |    45 36 |
   d9 | STO RAN#           |    44 36 |
   da | Py,x               |    42 40 |
   db | Re<>Im             |    42 30 |
   dc | PSE                |    42 31 |
   dd | CLEAR SIGMA        |    42 32 |
   dd | CLEAR S            |    42 32 |
   dd | CLR SIGMA          |    42 32 |
   dd | CLR S              |    42 32 |
   de | L.R.               |    42 49 |
   e0 | x bar              |    43  0 |
   e0 | x_                 |    43  0 |
   e0 | MEAN               |    43  0 |
   e1 | ->P                |    43  1 |
   e2 | ->H                |    43  2 |
   e3 | ->DEG              |    43  3 |
   e4 | ASINH              | 43,22,23 |
   e4 | HYP SIN^-1         | 43,22,23 |
   e5 | ACOSH              | 43,22,24 |
   e5 | HYP COS^-1         | 43,22,24 |
   e6 | ATANH              | 43,22,25 |
   e6 | HYP TAN^-1         | 43,22,25 |
   e7 | DEG                |    43  7 |
   e8 | RAD                |    43  8 |
   e9 | GRD                |    43  9 |
   ea | Cy,x               |    43 40 |
   eb | INT                |    43 44 |
   ec | x=0                |    43 20 |
   ec | x=0?               |    43 20 |
   ec | x==0               |    43 20 |
   ec | x==0?              |    43 20 |
   ed | x<=y               |    43 10 |
   ed | x<=y?              |    43 10 |
   ee | SIGMA-             |    43 49 |
   ee | S-                 |    43 49 |
   f0 | 0                  |        0 |
   f1 | 1                  |        1 |
   f2 | 2                  |        2 |
   f3 | 3                  |        3 |
   f4 | 4                  |        4 |
   f5 | 5                  |        5 |
   f6 | 6                  |        6 |
   f7 | 7                  |        7 |
   f8 | 8                  |        8 |
   f9 | 9                  |        9 |
   fa | +                  |       40 |
   fb | -                  |       30 |
   fc | x                  |       20 |
   fc | *                  |       20 |
   fd | /                  |       10 |
   fe | SIGMA+             |       49 |
   fe | S+                 |       49 |
 af5d | RCL g (i)          | - 45,43,24 |
 af6d | STO g (i)          | - 44,43,24 |
 bf3a | RCL user A         | u    45 11 |
 bf3b | RCL user B         | u    45 12 |
 bf3c | RCL user C         | u    45 13 |
 bf3d | RCL user D         | u    45 14 |
 bf3e | RCL user E         | u    45 15 |
 bf4a | STO user A         | u    44 11 |
 bf4b | STO user B         | u    44 12 |
 bf4c | STO user C         | u    44 13 |
 bf4d | STO user D         | u    44 14 |
 bf4e | STO user E         | u    44 15 |
 bf86 | RCL user (i)       | u    45 24 |
 bf96 | STO user (i)       | u    44 24 |
 cf80 | RCL+ 0             | - 45,40, 0 |
 cf81 | RCL+ 1             | - 45,40, 1 |
 cf82 | RCL+ 2             | - 45,40, 2 |
 cf83 | RCL+ 3             | - 45,40, 3 |
 cf84 | RCL+ 4             | - 45,40, 4 |
 cf85 | RCL+ 5             | - 45,40, 5 |
 cf86 | RCL+ 6             | - 45,40, 6 |
 cf87 | RCL+ 7             | - 45,40, 7 |
 cf88 | RCL+ 8             | - 45,40, 8 |
 cf89 | RCL+ 9             | - 45,40, 9 |
 cf8a | RCL+ A             | - 45,40,11 |
 cf8b | RCL+ B             | - 45,40,12 |
 cf8c | RCL+ C             | - 45,40,13 |
 cf8d | RCL+ D             | - 45,40,14 |
 cf8e | RCL+ E             | - 45,40,15 |
 cf90 | RCL+ .0            | - 45,40,.0 |
 cf91 | RCL+ .1            | - 45,40,.1 |
 cf92 | RCL+ .2            | - 45,40,.2 |
 cf93 | RCL+ .3            | - 45,40,.3 |
 cf94 | RCL+ .4            | - 45,40,.4 |
 cf95 | RCL+ .5            | - 45,40,.5 |
 cf96 | RCL+ .6            | - 45,40,.6 |
 cf97 | RCL+ .7            | - 45,40,.7 |
 cf98 | RCL+ .8            | - 45,40,.8 |
 cf99 | RCL+ .9            | - 45,40,.9 |
 cf9d | RCL+ (i)           | - 45,40,24 |
 cf9e | RCL+ I             | - 45,40,25 |
 cfa0 | RCL- 0             | - 45,30, 0 |
 cfa1 | RCL- 1             | - 45,30, 1 |
 cfa2 | RCL- 2             | - 45,30, 2 |
 cfa3 | RCL- 3             | - 45,30, 3 |
 cfa4 | RCL- 4             | - 45,30, 4 |
 cfa5 | RCL- 5             | - 45,30, 5 |
 cfa6 | RCL- 6             | - 45,30, 6 |
 cfa7 | RCL- 7             | - 45,30, 7 |
 cfa8 | RCL- 8             | - 45,30, 8 |
 cfa9 | RCL- 9             | - 45,30, 9 |
 cfaa | RCL- A             | - 45,30,11 |
 cfab | RCL- B             | - 45,30,12 |
 cfac | RCL- C             | - 45,30,13 |
 cfad | RCL- D             | - 45,30,14 |
 cfae | RCL- E             | - 45,30,15 |
 cfb0 | RCL- .0            | - 45,30,.0 |
 cfb1 | RCL- .1            | - 45,30,.1 |
 cfb2 | RCL- .2            | - 45,30,.2 |
 cfb3 | RCL- .3            | - 45,30,.3 |
 cfb4 | RCL- .4            | - 45,30,.4 |
 cfb5 | RCL- .5            | - 45,30,.5 |
 cfb6 | RCL- .6            | - 45,30,.6 |
 cfb7 | RCL- .7            | - 45,30,.7 |
 cfb8 | RCL- .8            | - 45,30,.8 |
 cfb9 | RCL- .9            | - 45,30,.9 |
 cfbd | RCL- (i)           | - 45,30,24 |
 cfbe | RCL- I             | - 45,30,25 |
 cfc0 | RCLx 0             | - 45,20, 0 |
 cfc0 | RCL* 0             | - 45,20, 0 |
 cfc1 | RCLx 1             | - 45,20, 1 |
 cfc1 | RCL* 1             | - 45,20, 1 |
 cfc2 | RCLx 2             | - 45,20, 2 |
 cfc2 | RCL* 2             | - 45,20, 2 |
 cfc3 | RCLx 3             | - 45,20, 3 |
 cfc3 | RCL* 3             | - 45,20, 3 |
 cfc4 | RCLx 4             | - 45,20, 4 |
 cfc4 | RCL* 4             | - 45,20, 4 |
 cfc5 | RCLx 5             | - 45,20, 5 |
 cfc5 | RCL* 5             | - 45,20, 5 |
 cfc6 | RCLx 6             | - 45,20, 6 |
 cfc6 | RCL* 6             | - 45,20, 6 |
 cfc7 | RCLx 7             | - 45,20, 7 |
 cfc7 | RCL* 7             | - 45,20, 7 |
 cfc8 | RCLx 8             | - 45,20, 8 |
 cfc8 | RCL* 8             | - 45,20, 8 |
 cfc9 | RCLx 9             | - 45,20, 9 |
 cfc9 | RCL* 9             | - 45,20, 9 |
 cfca | RCLx A             | - 45,20,11 |
 cfca | RCL* A             | - 45,20,11 |
 cfcb | RCLx B             | - 45,20,12 |
 cfcb | RCL* B             | - 45,20,12 |
 cfcc | RCLx C             | - 45,20,13 |
 cfcc | RCL* C             | - 45,20,13 |
 cfcd | RCLx D             | - 45,20,14 |
 cfcd | RCL* D             | - 45,20,14 |
 cfce | RCLx E             | - 45,20,15 |
 cfce | RCL* E             | - 45,20,15 |
 cfd0 | RCLx .0            | - 45,20,.0 |
 cfd0 | RCL* .0            | - 45,20,.0 |
 cfd1 | RCLx .1            | - 45,20,.1 |
 cfd1 | RCL* .1            | - 45,20,.1 |
 cfd2 | RCLx .2            | - 45,20,.2 |
 cfd2 | RCL* .2            | - 45,20,.2 |
 cfd3 | RCLx .3            | - 45,20,.3 |
 cfd3 | RCL* .3            | - 45,20,.3 |
 cfd4 | RCLx .4            | - 45,20,.4 |
 cfd4 | RCL* .4            | - 45,20,.4 |
 cfd5 | RCLx .5            | - 45,20,.5 |
 cfd5 | RCL* .5            | - 45,20,.5 |
 cfd6 | RCLx .6            | - 45,20,.6 |
 cfd6 | RCL* .6            | - 45,20,.6 |
 cfd7 | RCLx .7            | - 45,20,.7 |
 cfd7 | RCL* .7            | - 45,20,.7 |
 cfd8 | RCLx .8            | - 45,20,.8 |
 cfd8 | RCL* .8            | - 45,20,.8 |
 cfd9 | RCLx .9            | - 45,20,.9 |
 cfd9 | RCL* .9            | - 45,20,.9 |
 cfdd | RCLx (i)           | - 45,20,24 |
 cfdd | RCL* (i)           | - 45,20,24 |
 cfde | RCLx I             | - 45,20,25 |
 cfde | RCL* I             | - 45,20,25 |
 cfe0 | RCL/ 0             | - 45,10, 0 |
 cfe1 | RCL/ 1             | - 45,10, 1 |
 cfe2 | RCL/ 2             | - 45,10, 2 |
 cfe3 | RCL/ 3             | - 45,10, 3 |
 cfe4 | RCL/ 4             | - 45,10, 4 |
 cfe5 | RCL/ 5             | - 45,10, 5 |
 cfe6 | RCL/ 6             | - 45,10, 6 |
 cfe7 | RCL/ 7             | - 45,10, 7 |
 cfe8 | RCL/ 8             | - 45,10, 8 |
 cfe9 | RCL/ 9             | - 45,10, 9 |
 cfea | RCL/ A             | - 45,10,11 |
 cfeb | RCL/ B             | - 45,10,12 |
 cfec | RCL/ C             | - 45,10,13 |
 cfed | RCL/ D             | - 45,10,14 |
 cfee | RCL/ E             | - 45,10,15 |
 cff0 | RCL/ .0            | - 45,10,.0 |
 cff1 | RCL/ .1            | - 45,10,.1 |
 cff2 | RCL/ .2            | - 45,10,.2 |
 cff3 | RCL/ .3            | - 45,10,.3 |
 cff4 | RCL/ .4            | - 45,10,.4 |
 cff5 | RCL/ .5            | - 45,10,.5 |
 cff6 | RCL/ .6            | - 45,10,.6 |
 cff7 | RCL/ .7            | - 45,10,.7 |
 cff8 | RCL/ .8            | - 45,10,.8 |
 cff9 | RCL/ .9            | - 45,10,.9 |
 cffd | RCL/ (i)           | - 45,10,24 |
 cffe | RCL/ I             | - 45,10,25 |
 df80 | STO+ 0             | - 44,40, 0 |
 df81 | STO+ 1             | - 44,40, 1 |
 df82 | STO+ 2             | - 44,40, 2 |
 df83 | STO+ 3             | - 44,40, 3 |
 df84 | STO+ 4             | - 44,40, 4 |
 df85 | STO+ 5             | - 44,40, 5 |
 df86 | STO+ 6             | - 44,40, 6 |
 df87 | STO+ 7             | - 44,40, 7 |
 df88 | STO+ 8             | - 44,40, 8 |
 df89 | STO+ 9             | - 44,40, 9 |
 df8a | STO+ A             | - 44,40,11 |
 df8b | STO+ B             | - 44,40,12 |
 df8c | STO+ C             | - 44,40,13 |
 df8d | STO+ D             | - 44,40,14 |
 df8e | STO+ E             | - 44,40,15 |
 df90 | STO+ .0            | - 44,40,.0 |
 df91 | STO+ .1            | - 44,40,.1 |
 df92 | STO+ .2            | - 44,40,.2 |
 df93 | STO+ .3            | - 44,40,.3 |
 df94 | STO+ .4            | - 44,40,.4 |
 df95 | STO+ .5            | - 44,40,.5 |
 df96 | STO+ .6            | - 44,40,.6 |
 df97 | STO+ .7            | - 44,40,.7 |
 df98 | STO+ .8            | - 44,40,.8 |
 df99 | STO+ .9            | - 44,40,.9 |
 df9d | STO+ (i)           | - 44,40,24 |
 df9e | STO+ I             | - 44,40,25 |
 dfa0 | STO- 0             | - 44,30, 0 |
 dfa1 | STO- 1             | - 44,30, 1 |
 dfa2 | STO- 2             | - 44,30, 2 |
 dfa3 | STO- 3             | - 44,30, 3 |
 dfa4 | STO- 4             | - 44,30, 4 |
 dfa5 | STO- 5             | - 44,30, 5 |
 dfa6 | STO- 6             | - 44,30, 6 |
 dfa7 | STO- 7             | - 44,30, 7 |
 dfa8 | STO- 8             | - 44,30, 8 |
 dfa9 | STO- 9             | - 44,30, 9 |
 dfaa | STO- A             | - 44,30,11 |
 dfab | STO- B             | - 44,30,12 |
 dfac | STO- C             | - 44,30,13 |
 dfad | STO- D             | - 44,30,14 |
 dfae | STO- E             | - 44,30,15 |
 dfb0 | STO- .0            | - 44,30,.0 |
 dfb1 | STO- .1            | - 44,30,.1 |
 dfb2 | STO- .2            | - 44,30,.2 |
 dfb3 | STO- .3            | - 44,30,.3 |
 dfb4 | STO- .4            | - 44,30,.4 |
 dfb5 | STO- .5            | - 44,30,.5 |
 dfb6 | STO- .6            | - 44,30,.6 |
 dfb7 | STO- .7            | - 44,30,.7 |
 dfb8 | STO- .8            | - 44,30,.8 |
 dfb9 | STO- .9            | - 44,30,.9 |
 dfbd | STO- (i)           | - 44,30,24 |
 dfbe | STO- I             | - 44,30,25 |
 dfc0 | STOx 0             | - 44,20, 0 |
 dfc0 | STO* 0             | - 44,20, 0 |
 dfc1 | STOx 1             | - 44,20, 1 |
 dfc1 | STO* 1             | - 44,20, 1 |
 dfc2 | STOx 2             | - 44,20, 2 |
 dfc2 | STO* 2             | - 44,20, 2 |
 dfc3 | STOx 3             | - 44,20, 3 |
 dfc3 | STO* 3             | - 44,20, 3 |
 dfc4 | STOx 4             | - 44,20, 4 |
 dfc4 | STO* 4             | - 44,20, 4 |
 dfc5 | STOx 5             | - 44,20, 5 |
 dfc5 | STO* 5             | - 44,20, 5 |
 dfc6 | STOx 6             | - 44,20, 6 |
 dfc6 | STO* 6             | - 44,20, 6 |
 dfc7 | STOx 7             | - 44,20, 7 |
 dfc7 | STO* 7             | - 44,20, 7 |
 dfc8 | STOx 8             | - 44,20, 8 |
 dfc8 | STO* 8             | - 44,20, 8 |
 dfc9 | STOx 9             | - 44,20, 9 |
 dfc9 | STO* 9             | - 44,20, 9 |
 dfca | STOx A             | - 44,20,11 |
 dfca | STO* A             | - 44,20,11 |
 dfcb | STOx B             | - 44,20,12 |
 dfcb | STO* B             | - 44,20,12 |
 dfcc | STOx C             | - 44,20,13 |
 dfcc | STO* C             | - 44,20,13 |
 dfcd | STOx D             | - 44,20,14 |
 dfcd | STO* D             | - 44,20,14 |
 dfce | STOx E             | - 44,20,15 |
 dfce | STO* E             | - 44,20,15 |
 dfd0 | STOx .0            | - 44,20,.0 |
 dfd0 | STO* .0            | - 44,20,.0 |
 dfd1 | STOx .1            | - 44,20,.1 |
 dfd1 | STO* .1            | - 44,20,.1 |
 dfd2 | STOx .2            | - 44,20,.2 |
 dfd2 | STO* .2            | - 44,20,.2 |
 dfd3 | STOx .3            | - 44,20,.3 |
 dfd3 | STO* .3            | - 44,20,.3 |
 dfd4 | STOx .4            | - 44,20,.4 |
 dfd4 | STO* .4            | - 44,20,.4 |
 dfd5 | STOx .5            | - 44,20,.5 |
 dfd5 | STO* .5            | - 44,20,.5 |
 dfd6 | STOx .6            | - 44,20,.6 |
 dfd6 | STO* .6            | - 44,20,.6 |
 dfd7 | STOx .7            | - 44,20,.7 |
 dfd7 | STO* .7            | - 44,20,.7 |
 dfd8 | STOx .8            | - 44,20,.8 |
 dfd8 | STO* .8            | - 44,20,.8 |
 dfd9 | STOx .9            | - 44,20,.9 |
 dfd9 | STO* .9            | - 44,20,.9 |
 dfdd | STOx (i)           | - 44,20,24 |
 dfdd | STO* (i)           | - 44,20,24 |
 dfde | STOx I             | - 44,20,25 |
 dfde | STO* I             | - 44,20,25 |
 dfe0 | STO/ 0             | - 44,10, 0 |
 dfe1 | STO/ 1             | - 44,10, 1 |
 dfe2 | STO/ 2             | - 44,10, 2 |
 dfe3 | STO/ 3             | - 44,10, 3 |
 dfe4 | STO/ 4             | - 44,10, 4 |
 dfe5 | STO/ 5             | - 44,10, 5 |
 dfe6 | STO/ 6             | - 44,10, 6 |
 dfe7 | STO/ 7             | - 44,10, 7 |
 dfe8 | STO/ 8             | - 44,10, 8 |
 dfe9 | STO/ 9             | - 44,10, 9 |
 dfea | STO/ A             | - 44,10,11 |
 dfeb | STO/ B             | - 44,10,12 |
 dfec | STO/ C             | - 44,10,13 |
 dfed | STO/ D             | - 44,10,14 |
 dfee | STO/ E             | - 44,10,15 |
 dff0 | STO/ .0            | - 44,10,.0 |
 dff1 | STO/ .1            | - 44,10,.1 |
 dff2 | STO/ .2            | - 44,10,.2 |
 dff3 | STO/ .3            | - 44,10,.3 |
 dff4 | STO/ .4            | - 44,10,.4 |
 dff5 | STO/ .5            | - 44,10,.5 |
 dff6 | STO/ .6            | - 44,10,.6 |
 dff7 | STO/ .7            | - 44,10,.7 |
 dff8 | STO/ .8            | - 44,10,.8 |
 dff9 | STO/ .9            | - 44,10,.9 |
 dffd | STO/ (i)           | - 44,10,24 |
 dffe | STO/ I             | - 44,10,25 |
 ef10 | SOLVE 0            | - 42,10, 0 |
 ef11 | SOLVE 1            | - 42,10, 1 |
 ef12 | SOLVE 2            | - 42,10, 2 |
 ef13 | SOLVE 3            | - 42,10, 3 |
 ef14 | SOLVE 4            | - 42,10, 4 |
 ef15 | SOLVE 5            | - 42,10, 5 |
 ef16 | SOLVE 6            | - 42,10, 6 |
 ef17 | SOLVE 7            | - 42,10, 7 |
 ef18 | SOLVE 8            | - 42,10, 8 |
 ef19 | SOLVE 9            | - 42,10, 9 |
 ef1a | SOLVE A            | - 42,10,11 |
 ef1b | SOLVE B            | - 42,10,12 |
 ef1c | SOLVE C            | - 42,10,13 |
 ef1d | SOLVE D            | - 42,10,14 |
 ef1e | SOLVE E            | - 42,10,15 |
 ef20 | SOLVE .0           | - 42,10,.0 |
 ef21 | SOLVE .1           | - 42,10,.1 |
 ef22 | SOLVE .2           | - 42,10,.2 |
 ef23 | SOLVE .3           | - 42,10,.3 |
 ef24 | SOLVE .4           | - 42,10,.4 |
 ef25 | SOLVE .5           | - 42,10,.5 |
 ef26 | SOLVE .6           | - 42,10,.6 |
 ef27 | SOLVE .7           | - 42,10,.7 |
 ef28 | SOLVE .8           | - 42,10,.8 |
 ef29 | SOLVE .9           | - 42,10,.9 |
 ef30 | INTEGRATE 0        | - 42,20, 0 |
 ef30 | INTEG 0            | - 42,20, 0 |
 ef31 | INTEGRATE 1        | - 42,20, 1 |
 ef31 | INTEG 1            | - 42,20, 1 |
 ef32 | INTEGRATE 2        | - 42,20, 2 |
 ef32 | INTEG 2            | - 42,20, 2 |
 ef33 | INTEGRATE 3        | - 42,20, 3 |
 ef33 | INTEG 3            | - 42,20, 3 |
 ef34 | INTEGRATE 4        | - 42,20, 4 |
 ef34 | INTEG 4            | - 42,20, 4 |
 ef35 | INTEGRATE 5        | - 42,20, 5 |
 ef35 | INTEG 5            | - 42,20, 5 |
 ef36 | INTEGRATE 6        | - 42,20, 6 |
 ef36 | INTEG 6            | - 42,20, 6 |
 ef37 | INTEGRATE 7        | - 42,20, 7 |
 ef37 | INTEG 7            | - 42,20, 7 |
 ef38 | INTEGRATE 8        | - 42,20, 8 |
 ef38 | INTEG 8            | - 42,20, 8 |
 ef39 | INTEGRATE 9        | - 42,20, 9 |
 ef39 | INTEG 9            | - 42,20, 9 |
 ef3a | INTEGRATE A        | - 42,20,11 |
 ef3a | INTEG A            | - 42,20,11 |
 ef3b | INTEGRATE B        | - 42,20,12 |
 ef3b | INTEG B            | - 42,20,12 |
 ef3c | INTEGRATE C        | - 42,20,13 |
 ef3c | INTEG C            | - 42,20,13 |
 ef3d | INTEGRATE D        | - 42,20,14 |
 ef3d | INTEG D            | - 42,20,14 |
 ef3e | INTEGRATE E        | - 42,20,15 |
 ef3e | INTEG E            | - 42,20,15 |
 ef40 | INTEGRATE .0       | - 42,20,.0 |
 ef40 | INTEG .0           | - 42,20,.0 |
 ef41 | INTEGRATE .1       | - 42,20,.1 |
 ef41 | INTEG .1           | - 42,20,.1 |
 ef42 | INTEGRATE .2       | - 42,20,.2 |
 ef42 | INTEG .2           | - 42,20,.2 |
 ef43 | INTEGRATE .3       | - 42,20,.3 |
 ef43 | INTEG .3           | - 42,20,.3 |
 ef44 | INTEGRATE .4       | - 42,20,.4 |
 ef44 | INTEG .4           | - 42,20,.4 |
 ef45 | INTEGRATE .5       | - 42,20,.5 |
 ef45 | INTEG .5           | - 42,20,.5 |
 ef46 | INTEGRATE .6       | - 42,20,.6 |
 ef46 | INTEG .6           | - 42,20,.6 |
 ef47 | INTEGRATE .7       | - 42,20,.7 |
 ef47 | INTEG .7           | - 42,20,.7 |
 ef48 | INTEGRATE .8       | - 42,20,.8 |
 ef48 | INTEG .8           | - 42,20,.8 |
 ef49 | INTEGRATE .9       | - 42,20,.9 |
 ef49 | INTEG .9           | - 42,20,.9 |
#ef50 | x<>0               | - 42, 4, 0 |
#ef51 | x<>1               | - 42, 4, 1 |
 ef52 | x<>2               | - 42, 4, 2 |
 ef53 | x<>3               | - 42, 4, 3 |
 ef54 | x<>4               | - 42, 4, 4 |
 ef55 | x<>5               | - 42, 4, 5 |
 ef56 | x<>6               | - 42, 4, 6 |
 ef57 | x<>7               | - 42, 4, 7 |
 ef58 | x<>8               | - 42, 4, 8 |
 ef59 | x<>9               | - 42, 4, 9 |
 ef5a | x<>A               | - 42, 4,11 |
 ef5b | x<>B               | - 42, 4,12 |
 ef5c | x<>C               | - 42, 4,13 |
 ef5d | x<>D               | - 42, 4,14 |
 ef5e | x<>E               | - 42, 4,15 |
 ef60 | x<>.0              | - 42, 4,.0 |
 ef61 | x<>.1              | - 42, 4,.1 |
 ef62 | x<>.2              | - 42, 4,.2 |
 ef63 | x<>.3              | - 42, 4,.3 |
 ef64 | x<>.4              | - 42, 4,.4 |
 ef65 | x<>.5              | - 42, 4,.5 |
 ef66 | x<>.6              | - 42, 4,.6 |
 ef67 | x<>.7              | - 42, 4,.7 |
 ef68 | x<>.8              | - 42, 4,.8 |
 ef69 | x<>.9              | - 42, 4,.9 |
#ef70 | DSE 0              | - 42, 5, 0 |
#ef71 | DSE 1              | - 42, 5, 1 |
 ef72 | DSE 2              | - 42, 5, 2 |
 ef73 | DSE 3              | - 42, 5, 3 |
 ef74 | DSE 4              | - 42, 5, 4 |
 ef75 | DSE 5              | - 42, 5, 5 |
 ef76 | DSE 6              | - 42, 5, 6 |
 ef77 | DSE 7              | - 42, 5, 7 |
 ef78 | DSE 8              | - 42, 5, 8 |
 ef79 | DSE 9              | - 42, 5, 9 |
 ef7a | DSE A              | - 42, 5,11 |
 ef7b | DSE B              | - 42, 5,12 |
 ef7c | DSE C              | - 42, 5,13 |
 ef7d | DSE D              | - 42, 5,14 |
 ef7e | DSE E              | - 42, 5,15 |
 ef80 | DSE .0             | - 42, 5,.0 |
 ef81 | DSE .1             | - 42, 5,.1 |
 ef82 | DSE .2             | - 42, 5,.2 |
 ef83 | DSE .3             | - 42, 5,.3 |
 ef84 | DSE .4             | - 42, 5,.4 |
 ef85 | DSE .5             | - 42, 5,.5 |
 ef86 | DSE .6             | - 42, 5,.6 |
 ef87 | DSE .7             | - 42, 5,.7 |
 ef88 | DSE .8             | - 42, 5,.8 |
 ef89 | DSE .9             | - 42, 5,.9 |
#ef90 | ISG 0              | - 42, 6, 0 |
#ef91 | ISG 1              | - 42, 6, 1 |
 ef92 | ISG 2              | - 42, 6, 2 |
 ef93 | ISG 3              | - 42, 6, 3 |
 ef94 | ISG 4              | - 42, 6, 4 |
 ef95 | ISG 5              | - 42, 6, 5 |
 ef96 | ISG 6              | - 42, 6, 6 |
 ef97 | ISG 7              | - 42, 6, 7 |
 ef98 | ISG 8              | - 42, 6, 8 |
 ef99 | ISG 9              | - 42, 6, 9 |
 ef9a | ISG A              | - 42, 6,11 |
 ef9b | ISG B              | - 42, 6,12 |
 ef9c | ISG C              | - 42, 6,13 |
 ef9d | ISG D              | - 42, 6,14 |
 ef9e | ISG E              | - 42, 6,15 |
 efa0 | ISG .0             | - 42, 6,.0 |
 efa1 | ISG .1             | - 42, 6,.1 |
 efa2 | ISG .2             | - 42, 6,.2 |
 efa3 | ISG .3             | - 42, 6,.3 |
 efa4 | ISG .4             | - 42, 6,.4 |
 efa5 | ISG .5             | - 42, 6,.5 |
 efa6 | ISG .6             | - 42, 6,.6 |
 efa7 | ISG .7             | - 42, 6,.7 |
 efa8 | ISG .8             | - 42, 6,.8 |
 efa9 | ISG .9             | - 42, 6,.9 |
 ff00 | LBL .0             | - 42,21,.0 |
 ff01 | LBL .1             | - 42,21,.1 |
 ff02 | LBL .2             | - 42,21,.2 |
 ff03 | LBL .3             | - 42,21,.3 |
 ff04 | LBL .4             | - 42,21,.4 |
 ff05 | LBL .5             | - 42,21,.5 |
 ff06 | LBL .6             | - 42,21,.6 |
 ff07 | LBL .7             | - 42,21,.7 |
 ff08 | LBL .8             | - 42,21,.8 |
 ff09 | LBL .9             | - 42,21,.9 |
 ff10 | GTO .0             | -    22 .0 |
 ff11 | GTO .1             | -    22 .1 |
 ff12 | GTO .2             | -    22 .2 |
 ff13 | GTO .3             | -    22 .3 |
 ff14 | GTO .4             | -    22 .4 |
 ff15 | GTO .5             | -    22 .5 |
 ff16 | GTO .6             | -    22 .6 |
 ff17 | GTO .7             | -    22 .7 |
 ff18 | GTO .8             | -    22 .8 |
 ff19 | GTO .9             | -    22 .9 |
 ff20 | GSB .0             | -    32 .0 |
 ff21 | GSB .1             | -    32 .1 |
 ff22 | GSB .2             | -    32 .2 |
 ff23 | GSB .3             | -    32 .3 |
 ff24 | GSB .4             | -    32 .4 |
 ff25 | GSB .5             | -    32 .5 |
 ff26 | GSB .6             | -    32 .6 |
 ff27 | GSB .7             | -    32 .7 |
 ff28 | GSB .8             | -    32 .8 |
 ff29 | GSB .9             | -    32 .9 |
 ff30 | SF 0               | - 43, 4, 0 |
 ff31 | SF 1               | - 43, 4, 1 |
 ff32 | SF 2               | - 43, 4, 2 |
 ff33 | SF 3               | - 43, 4, 3 |
 ff34 | SF 4               | - 43, 4, 4 |
 ff35 | SF 5               | - 43, 4, 5 |
 ff36 | SF 6               | - 43, 4, 6 |
 ff37 | SF 7               | - 43, 4, 7 |
 ff38 | SF 8               | - 43, 4, 8 |
 ff39 | SF 9               | - 43, 4, 9 |
 ff3e | SF I               | - 43, 4,25 |
 ff40 | CF 0               | - 43, 5, 0 |
 ff41 | CF 1               | - 43, 5, 1 |
 ff42 | CF 2               | - 43, 5, 2 |
 ff43 | CF 3               | - 43, 5, 3 |
 ff44 | CF 4               | - 43, 5, 4 |
 ff45 | CF 5               | - 43, 5, 5 |
 ff46 | CF 6               | - 43, 5, 6 |
 ff47 | CF 7               | - 43, 5, 7 |
 ff48 | CF 8               | - 43, 5, 8 |
 ff49 | CF 9               | - 43, 5, 9 |
 ff4e | CF I               | - 43, 5,25 |
 ff50 | F? 0               | - 43, 6, 0 |
 ff51 | F? 1               | - 43, 6, 1 |
 ff52 | F? 2               | - 43, 6, 2 |
 ff53 | F? 3               | - 43, 6, 3 |
 ff54 | F? 4               | - 43, 6, 4 |
 ff55 | F? 5               | - 43, 6, 5 |
 ff56 | F? 6               | - 43, 6, 6 |
 ff57 | F? 7               | - 43, 6, 7 |
 ff58 | F? 8               | - 43, 6, 8 |
 ff59 | F? 9               | - 43, 6, 9 |
 ff5e | F? I               | - 43, 6,25 |
 ff60 | FIX 0              | - 42, 7, 0 |
 ff61 | FIX 1              | - 42, 7, 1 |
 ff62 | FIX 2              | - 42, 7, 2 |
 ff63 | FIX 3              | - 42, 7, 3 |
 ff64 | FIX 4              | - 42, 7, 4 |
 ff65 | FIX 5              | - 42, 7, 5 |
 ff66 | FIX 6              | - 42, 7, 6 |
 ff67 | FIX 7              | - 42, 7, 7 |
 ff68 | FIX 8              | - 42, 7, 8 |
 ff69 | FIX 9              | - 42, 7, 9 |
 ff6e | FIX I              | - 42, 7,25 |
 ff70 | SCI 0              | - 42, 8, 0 |
 ff71 | SCI 1              | - 42, 8, 1 |
 ff72 | SCI 2              | - 42, 8, 2 |
 ff73 | SCI 3              | - 42, 8, 3 |
 ff74 | SCI 4              | - 42, 8, 4 |
 ff75 | SCI 5              | - 42, 8, 5 |
 ff76 | SCI 6              | - 42, 8, 6 |
 ff77 | SCI 7              | - 42, 8, 7 |
 ff78 | SCI 8              | - 42, 8, 8 |
 ff79 | SCI 9              | - 42, 8, 9 |
 ff7e | SCI I              | - 42, 8,25 |
 ff80 | ENG 0              | - 42, 9, 0 |
 ff81 | ENG 1              | - 42, 9, 1 |
 ff82 | ENG 2              | - 42, 9, 2 |
 ff83 | ENG 3              | - 42, 9, 3 |
 ff84 | ENG 4              | - 42, 9, 4 |
 ff85 | ENG 5              | - 42, 9, 5 |
 ff86 | ENG 6              | - 42, 9, 6 |
 ff87 | ENG 7              | - 42, 9, 7 |
 ff88 | ENG 8              | - 42, 9, 8 |
 ff89 | ENG 9              | - 42, 9, 9 |
 ff8e | ENG I              | - 42, 9,25 |
 ff90 | MATRIX 0           | - 42,16, 0 |
 ff90 | MAT 0              | - 42,16, 0 |
 ff91 | MATRIX 1           | - 42,16, 1 |
 ff91 | MAT 1              | - 42,16, 1 |
 ff92 | MATRIX 2           | - 42,16, 2 |
 ff92 | MAT 2              | - 42,16, 2 |
 ff93 | MATRIX 3           | - 42,16, 3 |
 ff93 | MAT 3              | - 42,16, 3 |
 ff94 | MATRIX 4           | - 42,16, 4 |
 ff94 | MAT 4              | - 42,16, 4 |
 ff95 | MATRIX 5           | - 42,16, 5 |
 ff95 | MAT 5              | - 42,16, 5 |
 ff96 | MATRIX 6           | - 42,16, 6 |
 ff96 | MAT 6              | - 42,16, 6 |
 ff97 | MATRIX 7           | - 42,16, 7 |
 ff97 | MAT 7              | - 42,16, 7 |
 ff98 | MATRIX 8           | - 42,16, 8 |
 ff98 | MAT 8              | - 42,16, 8 |
 ff99 | MATRIX 9           | - 42,16, 9 |
 ff99 | MAT 9              | - 42,16, 9 |
 ffaa | STO MATRIX A       | - 44,16,11 |
 ffaa | STO MAT A          | - 44,16,11 |
 ffab | STO MATRIX B       | - 44,16,12 |
 ffab | STO MAT B          | - 44,16,12 |
 ffac | STO MATRIX C       | - 44,16,13 |
 ffac | STO MAT C          | - 44,16,13 |
 ffad | STO MATRIX D       | - 44,16,14 |
 ffad | STO MAT D          | - 44,16,14 |
 ffae | STO MATRIX E       | - 44,16,15 |
 ffae | STO MAT E          | - 44,16,15 |
15C Opcode End

15C Macro Start
&SMOD
LBL .9
-
LSTx
x<=y
GTO .9
Rv
&CALL_MOD
GSB .8
&MOD
LBL .8
x<>y
ENTER
Rv
x<>y
/
LSTx
x<>y
INT
*
R^
-
CHS
RTN
15C Macro End

15C New Start
<?xml version="1.0" encoding="ISO-8859-1"?>
<!DOCTYPE state SYSTEM "nonpareil.dtd">
<state version="1.00" model="15C" platform="voyager" arch="nut">
<ui/>
<chip name="Nut">
<registers>
<reg name="a" data="00000000000000"/>
<reg name="b" data="00000000000000"/>
<reg name="c" data="00000000000eae"/>
<reg name="m" data="00000000000000"/>
<reg name="n" data="00000000000000"/>
<reg name="g" data="09"/>
<reg name="p" data="c"/>
<reg name="q" data="4"/>
<reg name="q_sel" data="0"/>
<reg name="fo" data="00"/>
<reg name="s" data="0800"/>
<reg name="pc" data="0000"/>
<reg name="stack" index="0" data="009b"/>
<reg name="stack" index="1" data="0042"/>
<reg name="stack" index="2" data="0000"/>
<reg name="stack" index="3" data="0000"/>
<reg name="decimal" data="0"/>
<reg name="carry" data="0"/>
<reg name="awake" data="0"/>
<reg name="pf_addr" data="00"/>
<reg name="ram_addr" data="007"/>
<reg name="active_bank" index="0" data="0"/>
<reg name="active_bank" index="1" data="0"/>
<reg name="active_bank" index="2" data="0"/>
<reg name="active_bank" index="3" data="0"/>
<reg name="active_bank" index="4" data="0"/>
<reg name="active_bank" index="5" data="0"/>
<reg name="active_bank" index="6" data="0"/>
<reg name="active_bank" index="7" data="0"/>
<reg name="active_bank" index="8" data="0"/>
<reg name="active_bank" index="9" data="0"/>
<reg name="active_bank" index="a" data="0"/>
<reg name="active_bank" index="b" data="0"/>
<reg name="active_bank" index="c" data="0"/>
<reg name="active_bank" index="d" data="0"/>
<reg name="active_bank" index="e" data="0"/>
<reg name="active_bank" index="f" data="0"/>
</registers>
</chip>
<chip name="Voyager LCD">
<registers>
<reg name="enable" data="1"/>
<reg name="blink" data="0"/>
</registers>
</chip>
<memory as="ram">
<loc addr="000" data="00000000000000"/>
<loc addr="001" data="00000000000000"/>
<loc addr="002" data="00000000000000"/>
<loc addr="003" data="00000000000000"/>
<loc addr="004" data="00000000000000"/>
<loc addr="005" data="00000000000008"/>
<loc addr="006" data="0000000000000c"/>
<loc addr="007" data="00000000000eae"/>
<loc addr="008" data="00000000000000"/>
<loc addr="009" data="2faf8befbe2280"/>
<loc addr="00a" data="bef282bcbcaf80"/>
<loc addr="010" data="00000000000000"/>
<loc addr="011" data="00000000000000"/>
<loc addr="012" data="00000000000000"/>
<loc addr="013" data="00000000000000"/>
<loc addr="014" data="00000000000000"/>
<loc addr="015" data="c0d2d2d2d2d2d2"/>
<loc addr="016" data="00000000000000"/>
<loc addr="017" data="00000000000000"/>
<loc addr="018" data="00000000000000"/>
<loc addr="019" data="00000000000000"/>
<loc addr="01a" data="00000000a00000"/>
<loc addr="0c0" data="00000000000000"/>
<loc addr="0c1" data="00000000000000"/>
<loc addr="0c2" data="00000000000000"/>
<loc addr="0c3" data="00000000000000"/>
<loc addr="0c4" data="00000000000000"/>
<loc addr="0c5" data="00000000000000"/>
<loc addr="0c6" data="00000000000000"/>
<loc addr="0c7" data="00000000000000"/>
<loc addr="0c8" data="00000000000000"/>
<loc addr="0c9" data="00000000000000"/>
<loc addr="0ca" data="00000000000000"/>
<loc addr="0cb" data="00000000000000"/>
<loc addr="0cc" data="00000000000000"/>
<loc addr="0cd" data="00000000000000"/>
<loc addr="0ce" data="00000000000000"/>
<loc addr="0cf" data="00000000000000"/>
<loc addr="0d0" data="00000000000000"/>
<loc addr="0d1" data="00000000000000"/>
<loc addr="0d2" data="00000000000000"/>
<loc addr="0d3" data="00000000000000"/>
<loc addr="0d4" data="00000000000000"/>
<loc addr="0d5" data="00000000000000"/>
<loc addr="0d6" data="00000000000000"/>
<loc addr="0d7" data="00000000000000"/>
<loc addr="0d8" data="00000000000000"/>
<loc addr="0d9" data="00000000000000"/>
<loc addr="0da" data="00000000000000"/>
<loc addr="0db" data="00000000000000"/>
<loc addr="0dc" data="00000000000000"/>
<loc addr="0dd" data="00000000000000"/>
<loc addr="0de" data="00000000000000"/>
<loc addr="0df" data="00000000000000"/>
<loc addr="0e0" data="00000000000000"/>
<loc addr="0e1" data="00000000000000"/>
<loc addr="0e2" data="00000000000000"/>
<loc addr="0e3" data="00000000000000"/>
<loc addr="0e4" data="00000000000000"/>
<loc addr="0e5" data="00000000000000"/>
<loc addr="0e6" data="00000000000000"/>
<loc addr="0e7" data="00000000000000"/>
<loc addr="0e8" data="00000000000000"/>
<loc addr="0e9" data="00000000000000"/>
<loc addr="0ea" data="00000000000000"/>
<loc addr="0eb" data="00000000000000"/>
<loc addr="0ec" data="00000000000000"/>
<loc addr="0ed" data="00000000000000"/>
<loc addr="0ee" data="00000000000000"/>
<loc addr="0ef" data="00000000000000"/>
<loc addr="0f0" data="00000000000000"/>
<loc addr="0f1" data="00000000000000"/>
<loc addr="0f2" data="00000000000000"/>
<loc addr="0f3" data="00000000000000"/>
<loc addr="0f4" data="00000000000000"/>
<loc addr="0f5" data="00000000000000"/>
<loc addr="0f6" data="00000000000000"/>
<loc addr="0f7" data="00000000000000"/>
<loc addr="0f8" data="00000000000000"/>
<loc addr="0f9" data="00000000000000"/>
<loc addr="0fa" data="00000000000000"/>
<loc addr="0fb" data="00000000000000"/>
<loc addr="0fc" data="00000000000000"/>
<loc addr="0fd" data="00000000000000"/>
<loc addr="0fe" data="00000000000000"/>
<loc addr="0ff" data="00000000000000"/>
</memory>
</state>
15C New End

16C Opcode Start
#  op | code               | display  |
#-----+--------------------+----------+
   00 | LBL 0              | 43,22, 0 |
   01 | LBL 1              | 43,22, 1 |
   02 | LBL 2              | 43,22, 2 |
   03 | LBL 3              | 43,22, 3 |
   04 | LBL 4              | 43,22, 4 |
   05 | LBL 5              | 43,22, 5 |
   06 | LBL 6              | 43,22, 6 |
   07 | LBL 7              | 43,22, 7 |
   08 | LBL 8              | 43,22, 8 |
   09 | LBL 9              | 43,22, 9 |
   0a | LBL A              | 43,22, A |
   0b | LBL B              | 43,22, b |
   0c | LBL C              | 43,22, C |
   0d | LBL D              | 43,22, d |
   0e | LBL E              | 43,22, E |
   0f | LBL F              | 43,22, F |
   10 | SF 0               | 43, 4, 0 |
   11 | SF 1               | 43, 4, 1 |
   12 | SF 2               | 43, 4, 2 |
   13 | SF 3               | 43, 4, 3 |
   14 | SF 4               | 43, 4, 4 |
   15 | SF 5               | 43, 4, 5 |
   16 | WINDOW 0           | 43,36, 0 |
   17 | WINDOW 1           | 43,36, 1 |
   18 | WINDOW 2           | 43,36, 2 |
   19 | WINDOW 3           | 43,36, 3 |
   1a | WINDOW 4           | 43,36, 4 |
   1b | WINDOW 5           | 43,36, 5 |
   1c | WINDOW 6           | 43,36, 6 |
   1d | WINDOW 7           | 43,36, 7 |
#  1e | :1E                | 43,36, 8 |
#  1f | :1F                | 43,36, 9 |
   20 | CF 0               | 43, 5, 0 |
   21 | CF 1               | 43, 5, 1 |
   22 | CF 2               | 43, 5, 2 |
   23 | CF 3               | 43, 5, 3 |
   24 | CF 4               | 43, 5, 4 |
   25 | CF 5               | 43, 5, 5 |
   26 | FLOAT 0            | 42,45, 0 |
   27 | FLOAT 1            | 42,45, 1 |
   28 | FLOAT 2            | 42,45, 2 |
   29 | FLOAT 3            | 42,45, 3 |
   2a | FLOAT 4            | 42,45, 4 |
   2b | FLOAT 5            | 42,45, 5 |
#  2c | :2C                | 42,45, 6 |
#  2d | :2D                | 42,45, 7 |
#  2e | :2E                | 42,45, 8 |
#  2f | :2F                | 42,45, 9 |
   30 | F? 0               | 43, 6, 0 |
   31 | F? 1               | 43, 6, 1 |
   32 | F? 2               | 43, 6, 2 |
   33 | F? 3               | 43, 6, 3 |
   34 | F? 4               | 43, 6, 4 |
   35 | F? 5               | 43, 6, 5 |
   36 | FLOAT 6            | 42,45, 6 |
   37 | FLOAT 7            | 42,45, 7 |
   38 | FLOAT 8            | 42,45, 8 |
   39 | FLOAT 9            | 42,45, 9 |
   3a | FLOAT .            | 42,45,48 |
#  3b | :3B                | 42,45, b |
#  3c | :3C                | 42,45, C |
#  3d | :3D                | 42,45, d |
#  3e | :3E                | 42,45, E |
#  3f | :3F                | 42,45, F |
   40 | GTO 0              |    22  0 |
   41 | GTO 1              |    22  1 |
   42 | GTO 2              |    22  2 |
   43 | GTO 3              |    22  3 |
   44 | GTO 4              |    22  4 |
   45 | GTO 5              |    22  5 |
   46 | GTO 6              |    22  6 |
   47 | GTO 7              |    22  7 |
   48 | GTO 8              |    22  8 |
   49 | GTO 9              |    22  9 |
   4a | GTO A              |    22  A |
   4b | GTO B              |    22  b |
   4c | GTO C              |    22  C |
   4d | GTO D              |    22  d |
   4e | GTO E              |    22  E |
   4f | GTO F              |    22  F |
   50 | GSB 0              |    21  0 |
   51 | GSB 1              |    21  1 |
   52 | GSB 2              |    21  2 |
   53 | GSB 3              |    21  3 |
   54 | GSB 4              |    21  4 |
   55 | GSB 5              |    21  5 |
   56 | GSB 6              |    21  6 |
   57 | GSB 7              |    21  7 |
   58 | GSB 8              |    21  8 |
   59 | GSB 9              |    21  9 |
   5a | GSB A              |    21  A |
   5b | GSB B              |    21  b |
   5c | GSB C              |    21  C |
   5d | GSB D              |    21  d |
   5e | GSB E              |    21  E |
   5f | GSB F              |    21  F |
   60 | RCL 0              |    45  0 |
   61 | RCL 1              |    45  1 |
   62 | RCL 2              |    45  2 |
   63 | RCL 3              |    45  3 |
   64 | RCL 4              |    45  4 |
   65 | RCL 5              |    45  5 |
   66 | RCL 6              |    45  6 |
   67 | RCL 7              |    45  7 |
   68 | RCL 8              |    45  8 |
   69 | RCL 9              |    45  9 |
   6a | RCL A              |    45  A |
   6b | RCL B              |    45  b |
   6c | RCL C              |    45  C |
   6d | RCL D              |    45  d |
   6e | RCL E              |    45  E |
   6f | RCL F              |    45  F |
   70 | RCL .0             |    45 .0 |
   71 | RCL .1             |    45 .1 |
   72 | RCL .2             |    45 .2 |
   73 | RCL .3             |    45 .3 |
   74 | RCL .4             |    45 .4 |
   75 | RCL .5             |    45 .5 |
   76 | RCL .6             |    45 .6 |
   77 | RCL .7             |    45 .7 |
   78 | RCL .8             |    45 .8 |
   79 | RCL .9             |    45 .9 |
   7a | RCL .A             |    45 .A |
   7b | RCL .B             |    45 .b |
   7c | RCL .C             |    45 .C |
   7d | RCL .D             |    45 .d |
   7e | RCL .E             |    45 .E |
   7f | RCL .F             |    45 .F |
   80 | STO 0              |    44  0 |
   81 | STO 1              |    44  1 |
   82 | STO 2              |    44  2 |
   83 | STO 3              |    44  3 |
   84 | STO 4              |    44  4 |
   85 | STO 5              |    44  5 |
   86 | STO 6              |    44  6 |
   87 | STO 7              |    44  7 |
   88 | STO 8              |    44  8 |
   89 | STO 9              |    44  9 |
   8a | STO A              |    44  A |
   8b | STO B              |    44  b |
   8c | STO C              |    44  C |
   8d | STO D              |    44  d |
   8e | STO E              |    44  E |
   8f | STO F              |    44  F |
   90 | STO .0             |    44 .0 |
   91 | STO .1             |    44 .1 |
   92 | STO .2             |    44 .2 |
   93 | STO .3             |    44 .3 |
   94 | STO .4             |    44 .4 |
   95 | STO .5             |    44 .5 |
   96 | STO .6             |    44 .6 |
   97 | STO .7             |    44 .7 |
   98 | STO .8             |    44 .8 |
   99 | STO .9             |    44 .9 |
   9a | STO .A             |    44 .A |
   9b | STO .B             |    44 .b |
   9c | STO .C             |    44 .C |
   9d | STO .D             |    44 .d |
   9e | STO .E             |    44 .E |
   9f | STO .F             |    44 .F |
#  a0 | :A0                |    44 .0 |
   a1 | DSZ                |    43 23 |
   a2 | ISZ                |    43 24 |
   a3 | SQRT               |    43 25 |
   a3 | SQRT x             |    43 25 |
   a4 | 1/x                |    43 26 |
   a5 | R^                 |    43 33 |
   a5 | R-^                |    43 33 |
   a5 | RUP                |    43 33 |
   a5 | ROLL UP            |    43 33 |
   a6 | LSTx               |    43 36 |
   a6 | LASTx              |    43 36 |
   a7 | >                  |    43 45 |
   a8 | <                  |    43 44 |
   a9 | x!=0               |    43 48 |
   a9 | x!=0?              |    43 48 |
   a9 | x#0                |    43 48 |
   a9 | x#0?               |    43 48 |
   a9 | x=/=0              |    43 48 |
   a9 | x=/=0?             |    43 48 |
   aa | PSE                |    43 34 |
   ab | x=y                |    43 49 |
   ab | x=y?               |    43 49 |
   ab | x==y               |    43 49 |
   ab | x==y?              |    43 49 |
   ac | x=0                |    43 40 |
   ac | x=0?               |    43 40 |
   ac | x==0               |    43 40 |
   ac | x==0?              |    43 40 |
   ad | x>0                |    43 30 |
   ad | x>0?               |    43 30 |
   ae | DBLx               |    43 20 |
   af | DBL/               |    43 10 |
#  b0 | :B0                |        0 |
   b1 | SHOW HEX           |    42 23 |
   b2 | SHOW DEC           |    42 24 |
   b3 | SHOW OCT           |    42 25 |
   b4 | SHOW BIN           |    42 26 |
   b5 | RCL (i)            |    45 31 |
   b6 | RCL I              |    45 32 |
   b7 | GTO I              |    22 32 |
   b8 | WSIZE              |    42 44 |
   b9 | x<>(i)             |    42 21 |
   ba | CLEAR REG          |    42 34 |
   ba | CLR REG            |    42 34 |
   bb | EEX                |    42 49 |
   bc | OR                 |    42 40 |
   bd | NOT                |    42 30 |
   be | AND                |    42 20 |
   bf | XOR                |    42 10 |
   c0 | CLx                |    43 35 |
   c1 | HEX                |       23 |
   c2 | DEC                |       24 |
   c3 | OCT                |       25 |
   c4 | BIN                |       26 |
   c5 | Rv                 |       33 |
   c5 | R-v                |       33 |
   c5 | RDN                |       33 |
   c5 | ROLL DOWN          |       33 |
   c6 | ENTER              |       36 |
   c6 | ENTER^             |       36 |
   c7 | GSB I              |    21 32 |
   c8 | R/S                |       31 |
   c8 | RUN                |       31 |
   c8 | START              |       31 |
   c8 | STOP               |       31 |
   c9 | .                  |       48 |
   ca | x<>y               |       34 |
   ca | SWAP               |       34 |
   cb | CHS                |       49 |
   cb | +/-                |       49 |
   cc | +                  |       40 |
   cd | -                  |       30 |
   ce | x                  |       20 |
   ce | *                  |       20 |
   cf | /                  |       10 |
   d0 | x!=y               |    43  0 |
   d0 | x!=y?              |    43  0 |
   d0 | x#y                |    43  0 |
   d0 | x#y?               |    43  0 |
   d0 | x=/=y              |    43  0 |
   d0 | x=/=y?             |    43  0 |
   d1 | x<=y               |    43  1 |
   d1 | x<=y?              |    43  1 |
   d2 | x<0                |    43  2 |
   d2 | x<0?               |    43  2 |
   d3 | x>y                |    43  3 |
   d3 | x>y?               |    43  3 |
   d4 | RTN                |    43 21 |
   d5 | STO (i)            |    44 31 |
   d6 | STO I              |    44 32 |
   d7 | #B                 |    43  7 |
   d8 | ABS                |    43  8 |
   d9 | DBLR               |    43  9 |
   da | LJ                 |    43  A |
   db | ASR                |    43  b |
   dc | RLC                |    43  C |
   dd | RRC                |    43  d |
   de | RLCn               |    43  E |
   df | RRCn               |    43  F |
   e0 | x<>I               |    42 22 |
   e1 | SET COMPL 1'S      |    42  1 |
   e2 | SET COMPL 2'S      |    42  2 |
   e3 | SET COMPL UNSGN    |    42  3 |
   e4 | SB                 |    42  4 |
   e5 | CB                 |    42  5 |
   e6 | B?                 |    42  6 |
   e7 | MASKL              |    42  7 |
   e8 | MASKR              |    42  8 |
   e9 | RMD                |    42  9 |
   ea | SL                 |    42  A |
   eb | SR                 |    42  b |
   ec | RL                 |    42  C |
   ed | RR                 |    42  d |
   ee | RLn                |    42  E |
   ef | RRn                |    42  F |
   f0 | 0                  |        0 |
   f1 | 1                  |        1 |
   f2 | 2                  |        2 |
   f3 | 3                  |        3 |
   f4 | 4                  |        4 |
   f5 | 5                  |        5 |
   f6 | 6                  |        6 |
   f7 | 7                  |        7 |
   f8 | 8                  |        8 |
   f9 | 9                  |        9 |
   fa | A                  |        A |
   fb | B                  |        b |
   fc | C                  |        C |
   fd | D                  |        d |
   fe | E                  |        E |
   ff | F                  |        F |
16C Opcode End

16C Macro Start
16C Macro End

16C New Start
<?xml version="1.0" encoding="ISO-8859-1"?>
<!DOCTYPE state SYSTEM "nonpareil.dtd">
<state version="1.00" model="16C" platform="voyager" arch="nut">
<ui/>
<chip name="Nut">
<registers>
<reg name="a" data="00000000000000"/>
<reg name="b" data="f0000000000000"/>
<reg name="c" data="eae00000000000"/>
<reg name="m" data="00000000000000"/>
<reg name="n" data="00000000000000"/>
<reg name="g" data="02"/>
<reg name="p" data="c"/>
<reg name="q" data="3"/>
<reg name="q_sel" data="0"/>
<reg name="fo" data="00"/>
<reg name="s" data="0000"/>
<reg name="pc" data="0000"/>
<reg name="stack" index="0" data="0042"/>
<reg name="stack" index="1" data="003b"/>
<reg name="stack" index="2" data="0000"/>
<reg name="stack" index="3" data="0000"/>
<reg name="decimal" data="0"/>
<reg name="carry" data="0"/>
<reg name="awake" data="0"/>
<reg name="pf_addr" data="00"/>
<reg name="ram_addr" data="007"/>
<reg name="active_bank" index="0" data="0"/>
<reg name="active_bank" index="1" data="0"/>
<reg name="active_bank" index="2" data="0"/>
<reg name="active_bank" index="3" data="0"/>
<reg name="active_bank" index="4" data="0"/>
<reg name="active_bank" index="5" data="0"/>
<reg name="active_bank" index="6" data="0"/>
<reg name="active_bank" index="7" data="0"/>
<reg name="active_bank" index="8" data="0"/>
<reg name="active_bank" index="9" data="0"/>
<reg name="active_bank" index="a" data="0"/>
<reg name="active_bank" index="b" data="0"/>
<reg name="active_bank" index="c" data="0"/>
<reg name="active_bank" index="d" data="0"/>
<reg name="active_bank" index="e" data="0"/>
<reg name="active_bank" index="f" data="0"/>
</registers>
</chip>
<chip name="Voyager LCD">
<registers>
<reg name="enable" data="1"/>
<reg name="blink" data="0"/>
</registers>
</chip>
<memory as="ram">
<loc addr="000" data="00000000000000"/>
<loc addr="001" data="00000000000000"/>
<loc addr="002" data="00000000000000"/>
<loc addr="003" data="00000000000000"/>
<loc addr="004" data="f0000000000000"/>
<loc addr="005" data="f0000000000020"/>
<loc addr="006" data="02cf0000000000"/>
<loc addr="007" data="eae00000000000"/>
<loc addr="008" data="00000000000000"/>
<loc addr="009" data="00000000000000"/>
<loc addr="00a" data="5c0080bc000000"/>
<loc addr="0e0" data="00000000000000"/>
<loc addr="0e1" data="00000000000000"/>
<loc addr="0e2" data="00000000000000"/>
<loc addr="0e3" data="00000000000000"/>
<loc addr="0e4" data="00000000000000"/>
<loc addr="0e5" data="00000000000000"/>
<loc addr="0e6" data="00000000000000"/>
<loc addr="0e7" data="00000000000000"/>
<loc addr="0e8" data="00000000000000"/>
<loc addr="0e9" data="00000000000000"/>
<loc addr="0ea" data="00000000000000"/>
<loc addr="0eb" data="00000000000000"/>
<loc addr="0ec" data="00000000000000"/>
<loc addr="0ed" data="00000000000000"/>
<loc addr="0ee" data="00000000000000"/>
<loc addr="0ef" data="00000000000000"/>
<loc addr="0f0" data="00000000000000"/>
<loc addr="0f1" data="00000000000000"/>
<loc addr="0f2" data="00000000000000"/>
<loc addr="0f3" data="00000000000000"/>
<loc addr="0f4" data="00000000000000"/>
<loc addr="0f5" data="00000000000000"/>
<loc addr="0f6" data="00000000000000"/>
<loc addr="0f7" data="00000000000000"/>
<loc addr="0f8" data="00000000000000"/>
<loc addr="0f9" data="00000000000000"/>
<loc addr="0fa" data="00000000000000"/>
<loc addr="0fb" data="00000000000000"/>
<loc addr="0fc" data="00000000000000"/>
<loc addr="0fd" data="00000000000000"/>
<loc addr="0fe" data="00000000000000"/>
<loc addr="0ff" data="00000000000000"/>
</memory>
</state>
16C New End

